# Author: E. Korsching et al.
###############################################################################



# The workspace contains all the relevant data
# So, without changing it, the workspace is a --reference library-- for all intermediate and final results


## import of basic rMATS data  (very special for our situation - very likely might need changes in the R code)
## JC (junction count)
## JCEC (junction + exon count,  here: JCE )

## sv:  splice type aware - so in our case 5 splice types for JC and 5 splice types for JEC
## joined, join:  all splice types of one set joined -> so one JC and one JEC subset is the outcome for one sample set


# basic path
bpath <- "/../rmats_out_folder"
# experiment input table
expID <- list.files(path=bpath)
# order like it should be
expID <- data.frame(expID[c(13,7,6,11,5,8,9,2,3,10,4,1,15,16,17,18)],stringsAsFactors=F)
# splice variant table   (see sv variable: is reflecting the rmats output data structure on the file system level)
sv <- read.table(file="/../sType.txt", header=F, sep="\t", dec=".", stringsAsFactors=F)

# customize out variables
ido <- ""
for(i in expID[,1]){
	ido <- c(ido, paste("e", paste(unlist(strsplit(i, split="_")),collapse="."), sep=".") )
}
ido <- ido[-1]

#
svo <- ""
for(i in sv[1:5,1]){
	svo <- c(svo, paste(substr(i,1,2),".JC",sep="") )
}
svo <- svo[-1]
for(i in sv[6:10,1]){
	svo <- c(svo, paste(substr(i,1,2),".JEC",sep="") )
}
svo
# 160 imports (16*10)


# import in ordered way
e.sample.names <- vector("character",160)
a <- 1
for(i in 1:(length(ido))){		# ==expID
	for(j in 1:(length(svo))){		# ==sv
		tmpN <- paste(ido[i],svo[j],sep=".")
		cat("\n name ",tmpN)
		tmpV <- read.table(paste(bpath,"/",expID[i,1],"/",sv[j,1],sep=""), header=T, sep="\t", dec=".", stringsAsFactors=F)
		cat("\n import ",paste(bpath,"/",expID[i,1],"/",sv[j,1],sep=""))
		assign(x=tmpN, value=tmpV)
		e.sample.names[a] <- tmpN		# save names
		a <- a+1
	}
}



## create IDNEW + shrink to FDR<0.05 + some rMATS results statistics
ab.old <- ab
ab <- data.frame(c(names(e.sp.nsp.SE.JC)[1:11],"","",names(e.sp.nsp.SE.JC)[12:23]),	# column 6-11
				c(names(e.sp.nsp.A5.JC)[1:11],"","",names(e.sp.nsp.A5.JC)[12:23]),	# column 6-11
				c(names(e.sp.nsp.A3.JC)[1:11],"","",names(e.sp.nsp.A3.JC)[12:23]),	# column 6-11
				names(e.sp.nsp.MX.JC),													# column 6-13
				c(names(e.sp.nsp.RI.JC)[1:11],"","",names(e.sp.nsp.RI.JC)[12:23]) )	# column 6-11

# of all 5 splice variants take the physical "..._0base" position of the import tables - 6th column -
# to distinguish different splice regions inside one gene

# note :
# 1)  IDNEW is only a pointer to the original tables
# 2)  IDNEW is, in a limited way, showing (not exhaustively) where many alterations in one gene happens
#               the approach covers nearly all results, and is only used for some basic comparisons


# significant sample hits FDR
e.sample.hits <- data.frame(matrix(0,160,2))		# adjust matrix size
dimnames(e.sample.hits)[[2]] <- c("sample","hit.num.FDR")
a3 <- 1
for(i in e.sample.names){
	a <- c( "IDNEW", names(get(i)) )
	a1 <- cbind( paste( get(i)[,"geneSymbol"],get(i)[,6], sep="_"), get(i) , stringsAsFactors=F)
	names(a1) <- a						# IDNEW
	# shrink down to FDR<0.05
	a2 <- a1[,"FDR"]<0.05
	a1 <- a1[a2, ]
	a1 <- a1[order(a1[,"FDR"]),]
	assign(x=i, value=a1)
	e.sample.hits[a3,1] <- i
	e.sample.hits[a3,2] <- sum(a2)		# hits
	a3 <- a3+1
}

write.table(e.sample.hits, paste(bpath,"/sign.sample.hits.txt",sep=""), row.names=F, col.names=T)

# BC
f0(x=list(s.BC), prefix="sign.sample.hits.BC", path=bpath)

save.image()




####  intersections
# according to experimental design Figure

#  B   sp.nsp		(ERG)
#  C1  nsp.nst
#  C2  nsp.nso
#  D   sp.MSC
#  B2  nsp.MSC
#
#  H1  sp.es1		(ERG)
#  H2  sp.es2		(FLI1)
#  G1  nsp.es1		(ERG)
#  G2  nsp.es2		(FLI1)
#
#  E1  sp.hfb		(control)
#  E2  nsp.hfb
#  E3  msc.hfb

# new naming scheme  -  group.spliceType.countType
e.sample.names <- e.sample.names[c(1:120)]		# define the order - (!)without variance samples, separate approach
a <- rep(c(rep("JC",5),rep("JEC",5)),12)		# adjust size
a1 <- rep(rep(c("SE","A5","A3","MX","RI"),2),12)
a2 <- c(rep("B",10),rep("C1",10),rep("C2",10),rep("D",10),rep("B2",10),rep("H1erg",10),rep("H2fli",10),rep("G1erg",10),rep("G2fli",10), rep("E1",10),rep("E2",10),rep("E3",10))
e.sample.names2 <- paste(a2,a1,a,sep=".")			# C1 nst  C2 nso


# create new sample names
a <- 1
for(i in e.sample.names){
	assign(x=e.sample.names2[a], value=get(i))
	a <- a+1
}
# manual deletion of imported sample (names): e.xx  (no longer used)


#### join groups in one variable
s.B  <- f1(x=e.sample.names2[1:10])			# ERG
s.C1 <- f1(x=e.sample.names2[11:20])
s.C2 <- f1(x=e.sample.names2[21:30])
s.D  <- f1(x=e.sample.names2[31:40])
s.B2 <- f1(x=e.sample.names2[41:50])
s.H1 <- f1(x=e.sample.names2[51:60])		# ERG
s.H2 <- f1(x=e.sample.names2[61:70])		# FLI1
s.G1 <- f1(x=e.sample.names2[71:80])		# ERG
s.G2 <- f1(x=e.sample.names2[81:90])		# FLI1

s.E1 <- f1(x=e.sample.names2[91:100])
s.E2 <- f1(x=e.sample.names2[101:110])
s.E3 <- f1(x=e.sample.names2[111:120])
# manual deletion of imported samples:  G1erg.A3.JC, etc.


#### intersections
# 
s.C1uC2 <- f2(x=s.C1, y=s.C2, idv=c(1,1), setfn="u", repl="C1uC2")

s.BCpre <- f2(x=s.C1uC2, y=s.B, idv=c(0,1), setfn="ue", repl="BCpre")		# 1: C1 C2, 2: BC


#
s.BC <- f3(x=s.BCpre, num=2, repl="BC")


#
s.BCiDiB2 <- f4(x=s.BC, y=s.D, z=s.B2, idv=c(0,1,1), setfn="ic", repl="BCiDiB2")		# core intersection nsp msc sp

s.BCeDeB2 <- f4(x=s.BC, y=s.D, z=s.B2, idv=c(0,1,1), setfn="ue", repl="BCeDeB2")	# 1: BC, 2: D, 3: B2

# overlap D unique B2 unique
s.BCunique <- f3(x=s.BCeDeB2, num=1, repl="BCuni")
s.Dunique <- f3(x=s.BCeDeB2, num=2, repl="Duni")
s.B2unique <- f3(x=s.BCeDeB2, num=3, repl="B2uni")

s.DuniIB2uni <- f2(x=s.Dunique, y=s.B2unique, idv=c(0,0), setfn="ic", repl="DuniIB2uni")		# partly same genes - but no position identity - so non is identical!


# primary ERG FLI1
s.G1iG2 <- f2(x=s.G1, y=s.G2, idv=c(1,1), setfn="ic", repl="G1iG2")

s.G1eG2 <- f2(x=s.G1, y=s.G2, idv=c(1,1), setfn="ue", repl="G1eG2")

# single sets
s.G1unique <- f3(x=s.G1eG2, num=1, repl="G1uni")
s.G2unique <- f3(x=s.G1eG2, num=2, repl="G2uni")

#
s.H1iH2 <- f2(x=s.H1, y=s.H2, idv=c(1,1), setfn="ic", repl="H1iH2")

s.H1eH2 <- f2(x=s.H1, y=s.H2, idv=c(1,1), setfn="ue", repl="H1eH2")

# single sets
s.H1unique <- f3(x=s.H1eH2, num=1, repl="H1uni")
s.H2unique <- f3(x=s.H1eH2, num=2, repl="H2uni")

#
s.G1uniIH1uni <- f2(x=s.G1unique, y=s.H1unique, idv=c(0,0), setfn="ic", repl="G1uniIH1uni")
s.G2uniIH2uni <- f2(x=s.G2unique, y=s.H2unique, idv=c(0,0), setfn="ic", repl="G2uniIH2uni")



# hu-fib
s.E1iE2iE3 <- f4(x=s.E1, y=s.E2, z=s.E3, idv=c(1,1,1), setfn="ic", repl="E1iE2iE3")

s.E1eE2eE3 <- f4(x=s.E1, y=s.E2, z=s.E3, idv=c(1,1,1), setfn="ue", repl="E1eE2eE3")

# single sets
s.E1unique <- f3(x=s.E1eE2eE3, num=1, repl="E1uni")
s.E2unique <- f3(x=s.E1eE2eE3, num=2, repl="E2uni")
s.E3unique <- f3(x=s.E1eE2eE3, num=3, repl="E3uni")


# core sets
s.B2iBC <- f2(x=s.B2, y=s.BC, idv=c(1,0), setfn="ic", repl="B2iBC")
s.B2iD <- f2(x=s.B2, y=s.D, idv=c(1,1), setfn="ic", repl="B2iD")
s.DiBC <- f2(x=s.D, y=s.BC, idv=c(1,0), setfn="ic", repl="DiBC")

s.pre.nsp <- f2(x=s.B2iBC, y=s.BCiDiB2, idv=c(0,0), setfn="ue", repl="B2iBCeBCiDiB2")			# ok - 'ue' special case: 100% intersection on one side, therefore 0
s.pre.msc <- f2(x=s.B2iD, y=s.BCiDiB2, idv=c(0,0), setfn="ue", repl="B2iDeBCiDiB2")
s.pre.sp <- f2(x=s.DiBC, y=s.BCiDiB2, idv=c(0,0), setfn="ue", repl="DiBCeBCiDiB2")

# final
s.x.nsp <- f3(x=s.pre.nsp, num=1, repl="nsp")
s.x.msc <- f3(x=s.pre.msc, num=1, repl="msc")
s.x.sp <- f3(x=s.pre.sp, num=1, repl="sp")

# control overlap
s.x.sp.msc <- f2(x=s.x.sp, y=s.x.msc, idv=c(0,0), setfn="ic", repl="B2iBC")		# 0 - ok
s.x.sp.nsp <- f2(x=s.x.sp, y=s.x.nsp, idv=c(0,0), setfn="ic", repl="B2iBC")		# 0
s.x.nsp.msc <- f2(x=s.x.nsp, y=s.x.msc, idv=c(0,0), setfn="ic", repl="B2iBC")	# 0


# export counts
f0(x=list(s.x.sp,s.x.nsp,s.x.msc, s.BCunique,s.B2unique,s.Dunique), prefix="sign.core.hits.unique", path=bpath)


# cf. set B'
s.B2uD <- f2(x=s.B2, y=s.D, idv=c(1,1), setfn="u", repl="B2uD")
s.BiB2uD <- f2(x=s.B, y=s.B2uD, idv=c(1,0), setfn="ue", repl="BiB2uD")
s.Bp.B2uD <- f3(x=s.BiB2uD, num=1, repl="BiB2uD")

s.BpIBCp <- f2(x=s.Bp.B2uD, y=s.BCunique, idv=c(0,0), setfn="ic", repl="BpIBCp")	# B' BC'


# export counts
f0(x=list(s.Bp.B2uD, s.BCunique, s.BpIBCp), prefix="sign.Bp.BCp.BpIBCp.hits.unique", path=bpath)	# B' BC' and intersection of both


## export overlap table - new
a1 <- ls(pattern="^s\\.")
# customize - remove objects with "e" structure
a1 <- a1[-c(8,10,12,23,31,39,44:46)]
f0.1(x=a1, path=paste(bpath,"/0gene_overlap_statistics_on_s.txt",sep=""))


## export overlap table - new2
a <- c("s.B","s.C1","s.C2","s.D","s.B2","s.H1","s.H2","s.G1","s.G2", "s.E1","s.E2","s.E3")
a1 <- f11.0(x.name=a, path.n="results/stat.unique.txt", colnames=c("IDNEW","geneSymbol"))
write.table(a1, file=paste(bpath,"/0gene_overlap_statistics_on_s_2.txt",sep=""), sep="\t", row.names=F, col.names=T)

save.image()



#### export basic sets for   suppl.info. ST1   in tsv sheets
a <- c("s.B","s.C1","s.C2","s.D","s.B2","s.H1","s.H2","s.G1","s.G2", "s.E1","s.E2","s.E3")
for(i in 1:length(a)){
	b <- get(a[i])
	a1 <- names(b)
	for(j in 1:length(a1)){
		write.table(b[[a1[j]]], file=paste(bpath,"/",a[i],".",a1[j],".tsv",sep=""), sep="\t", row.names=F, col.names=T)
	}
}

# Export BC
b <- get("s.BC")
a1 <- names(b)
for(j in 1:length(a1)){
	write.table(b[[a1[j]]], file=paste(bpath,"/s.BC.",a1[j],".txt",sep=""), sep="\t", row.names=F, col.names=T)
}





#### Now we leave the IDnew concept again - split off position   [a historical remnant, which could be done differently now ...]

# transform again 's.' objects:  strip position information from gene name for GOA or else


# checks

# get full tables by IDs
# first element determines the size
sum( s.G1$G1.SE.JC[,1]%in%s.G1unique$G1uni.SE.JC )		# 872 , 410 -> 429    (! some duplicates)
a <- s.G1$G1.SE.JC[ s.G1$G1.SE.JC[,1]%in%s.G1unique$G1uni.SE.JC , ]

# review workspace
setdiff(ls(), lsf.str())		# objects without functions




#### transform for own GOA										--s sets, splice type aware
# basic
s1.B <- f5.1(x=s.B, strip=F, colNum=4)

s1.BC <- f5.1(x=s.BC, strip=T, colNum=NULL)
s1.B2 <- f5.1(x=s.B2, strip=F, colNum=4)
s1.D <- f5.1(x=s.D, strip=F, colNum=4)

# erg-fli differences
s1.G1iG2 <- f5.1(x=s.G1iG2, strip=T, colNum=NULL)
s1.H1iH2 <- f5.1(x=s.H1iH2, strip=T, colNum=NULL)

s1.G1unique <- f5.1(x=s.G1unique, strip=T, colNum=NULL)
s1.G2unique <- f5.1(x=s.G2unique, strip=T, colNum=NULL)

s1.H1unique <- f5.1(x=s.H1unique, strip=T, colNum=NULL)
s1.H2unique <- f5.1(x=s.H2unique, strip=T, colNum=NULL)

s1.G1uniIH1uni <- f5.1(x=s.G1uniIH1uni, strip=T, colNum=NULL)
s1.G2uniIH2uni <- f5.1(x=s.G2uniIH2uni, strip=T, colNum=NULL)

# fib controls ?  --> everthing is different ...
s1.E1iE2iE3 <- f5.1(x=s.E1iE2iE3, strip=T, colNum=NULL)
s1.E1unique <- f5.1(x=s.E1unique, strip=T, colNum=NULL)
s1.E2unique <- f5.1(x=s.E2unique, strip=T, colNum=NULL)
s1.E3unique <- f5.1(x=s.E3unique, strip=T, colNum=NULL)

# core
s1.BCiDiB2 <- f5.1(x=s.BCiDiB2, strip=T, colNum=NULL)
s1.BCunique <- f5.1(x=s.BCunique, strip=T, colNum=NULL)
s1.B2unique <- f5.1(x=s.B2unique, strip=T, colNum=NULL)
s1.Dunique <- f5.1(x=s.Dunique, strip=T, colNum=NULL)

s1.x.msc <- f5.1(x=s.x.msc, strip=T, colNum=NULL)
s1.x.nsp <- f5.1(x=s.x.nsp, strip=T, colNum=NULL)
s1.x.sp <- f5.1(x=s.x.sp, strip=T, colNum=NULL)

## export
a1 <- ls(pattern="^s1\\.")
f5.2(a1, path="results1.s1", colnum=NULL)




#### join all separate splice variants to one set and look again				--u sets, joined splice types--
# join data structure to one list element each jc jec

# join all s.* experiments

ls(pattern="^s\\.")		# 49

## not considered
#s.BCeDeB2
#s.BCpre
#s.DuniIB2uni  0
#s.G1eG2
#s.H1eH2
#s.E1eE2eF1
#u.E1
#u.E2
#u.E3
#u.C1
#u.C2
#u.C1uC2

# out of basic, core
u.G1 <- f8(x=s1.BC, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.G2
u.H1
u.H2



# basic
u.BC <- f8(x=s1.BC, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.B2 <- f8(x=s1.B2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.D <- f8(x=s1.D, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)

u.G1iG2 <- f8(x=s1.G1iG2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.H1iH2 <- f8(x=s1.H1iH2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.G1unique <- f8(x=s1.G1unique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.G2unique <- f8(x=s1.G2unique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.H1unique <- f8(x=s1.H1unique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.H2unique <- f8(x=s1.H2unique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.G1uniIH1uni <- f8(x=s1.G1uniIH1uni, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.G2uniIH2uni <- f8(x=s1.G2uniIH2uni, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)

u.E1iE2iE3 <- f8(x=s1.E1iE2iE3, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.E1unique <- f8(x=s1.E1unique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.E2unique <- f8(x=s1.E2unique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.E3unique <- f8(x=s1.E3unique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)

# core
u.BCiDiB2 <- f8(x=s1.BCiDiB2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.BCunique <- f8(x=s1.BCunique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.B2unique <- f8(x=s1.B2unique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.Dunique <- f8(x=s1.Dunique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)

u.x.msc <- f8(x=s1.x.msc, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.x.nsp <- f8(x=s1.x.nsp, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
u.x.sp <- f8(x=s1.x.sp, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)




#### some additional intersections on sv and the joined level			--followed--
s1.G1 <- f5.1(x=s.G1, strip=F, colNum=4)	# genes
u.G1 <- f8(x=s1.G1, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s1.G2 <- f5.1(x=s.G2, strip=F, colNum=4)
u.G2 <- f8(x=s1.G2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s1.H1 <- f5.1(x=s.H1, strip=F, colNum=4)
u.H1 <- f8(x=s1.H1, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s1.H2 <- f5.1(x=s.H2, strip=F, colNum=4)
u.H2 <- f8(x=s1.H2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)

s2.G1 <- f5.1(x=s.G1, strip=F, colNum=1)	# genes + location
u2.G1 <- f8(x=s2.G1, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s2.G2 <- f5.1(x=s.G2, strip=F, colNum=1)
u2.G2 <- f8(x=s2.G2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s2.H1 <- f5.1(x=s.H1, strip=F, colNum=1)
u2.H1 <- f8(x=s2.H1, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s2.H2 <- f5.1(x=s.H2, strip=F, colNum=1)
u2.H2 <- f8(x=s2.H2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)

s2.nsp <- f5.1(x=s.x.nsp, strip=F, colNum=NULL)
u2.nsp <- f8(x=s2.nsp, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s2.BCunique <- f5.1(x=s.BCunique, strip=F, colNum=NULL)
u2.BCunique <- f8(x=s2.BCunique, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)


s1.E1 <- f5.1(x=s.E1, strip=F, colNum=4)	# genes
u.E1 <- f8(x=s1.E1, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s1.E2 <- f5.1(x=s.E2, strip=F, colNum=4)
u.E2 <- f8(x=s1.E2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s1.E3 <- f5.1(x=s.E3, strip=F, colNum=4)
u.E3 <- f8(x=s1.E3, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)

s2.E1 <- f5.1(x=s.E1, strip=F, colNum=1)	# genes + location
u2.E1 <- f8(x=s2.E1, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s2.E2 <- f5.1(x=s.E2, strip=F, colNum=1)
u2.E2 <- f8(x=s2.E2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s2.E3 <- f5.1(x=s.E3, strip=F, colNum=1)
u2.E3 <- f8(x=s2.E3, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)

s2.D <- f5.1(x=s.D, strip=F, colNum=1)	# genes + location
u2.D <- f8(x=s2.D, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s2.B2 <- f5.1(x=s.B2, strip=F, colNum=1)
u2.B2 <- f8(x=s2.B2, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)
s2.BC <- f5.1(x=s.BC, strip=F, colNum=NULL)
u2.BC <- f8(x=s2.BC, groupSets=list(JC=c(1,2,3,4,5),JEC=c(6,7,8,9,10)), df=F)

## H1 H2 i BC  gene names
s1.2.BCiH1iH2 <- f4(x=s1.BC, y=s1.H1, z=s1.H2, idv=c(0,0,0), setfn="ic", repl="BCiH1iH2")
s1.2.BCiH1 <- f2(x=s1.BC, y=s1.H1, idv=c(0,0), setfn="ic", repl="BCiH1")
s1.2.BCiH2 <- f2(x=s1.BC, y=s1.H2, idv=c(0,0), setfn="ic", repl="BCiH2")

u.2.BCiH1iH2 <- f4.1(x=u.BC, y=u.H1, z=u.H2, idv=c(0,0,0), setfn="ic", repl="BCiH1iH2")
u.2.BCiH1 <- f2.1(x=u.BC, y=u.H1, idv=c(0,0), setfn="ic", repl="BCiH1")
u.2.BCiH2 <- f2.1(x=u.BC, y=u.H2, idv=c(0,0), setfn="ic", repl="BCiH2")

u.2.BCuniIH1iH2 <- f4.1(x=u.BCunique, y=u.H1, z=u.H2, idv=c(0,0,0), setfn="ic", repl="BCiH1iH2")
u.2.BCuniIH1 <- f2.1(x=u.BCunique, y=u.H1, idv=c(0,0), setfn="ic", repl="BCiH1")
u.2.BCuniIH2 <- f2.1(x=u.BCunique, y=u.H2, idv=c(0,0), setfn="ic", repl="BCiH2")

# G1 G2 i NSP gene names
s1.2.NSPiG1iG2 <- f4(x=s1.x.nsp, y=s1.G1, z=s1.G2, idv=c(0,0,0), setfn="ic", repl="NSPiG1iG2")
s1.2.NSPiG1 <- f2(x=s1.x.nsp, y=s1.G1, idv=c(0,0), setfn="ic", repl="NSPiG1")
s1.2.NSPiG2 <- f2(x=s1.x.nsp, y=s1.G2, idv=c(0,0), setfn="ic", repl="NSPiG2")

u.2.NSPiG1iG2 <- f4.1(x=u.x.nsp, y=u.G1, z=u.G2, idv=c(0,0,0), setfn="ic", repl="NSPiG1iG2")
u.2.NSPiG1 <- f2.1(x=u.x.nsp, y=u.G1, idv=c(0,0), setfn="ic", repl="NSPiG1")
u.2.NSPiG2 <- f2.1(x=u.x.nsp, y=u.G2, idv=c(0,0), setfn="ic", repl="NSPiG2")

# there is an overlap in genes

## H1 H2 i BC  gene names + location
u.3.BCuniIH1iH2 <- f4.1(x=u2.BCunique, y=u2.H1, z=u.H2, idv=c(0,0,0), setfn="ic", repl="BCuniIH1iH2")
u.3.BCuniIH1 <- f2.1(x=u2.BCunique, y=u2.H1, idv=c(0,0), setfn="ic", repl="BCuniIH1")
u.3.BCuniIH2 <- f2.1(x=u2.BCunique, y=u2.H2, idv=c(0,0), setfn="ic", repl="BCuniIH2")

u.3.BCiH1 <- f2.1(x=u2.BC, y=u2.H1, idv=c(0,0), setfn="ic", repl="BCiH1")
u.3.BCiH2 <- f2.1(x=u2.BC, y=u2.H2, idv=c(0,0), setfn="ic", repl="BCiH2")

# G1 G2 i NSP gene names + location
u.3.NSPiG1iG2 <- f4.1(x=u2.nsp, y=u2.G1, z=u.G2, idv=c(0,0,0), setfn="ic", repl="NSPiG1iG2")
u.3.NSPiG1 <- f2.1(x=u2.nsp, y=u2.G1, idv=c(0,0), setfn="ic", repl="NSPiG1")
u.3.NSPiG2 <- f2.1(x=u2.nsp, y=u2.G2, idv=c(0,0), setfn="ic", repl="NSPiG2")

# there is an smaller overlap in genes

# export gene name lists
a1 <- c("s1.2.BCiH1iH2","s1.2.BCiH1","s1.2.BCiH2","s1.2.NSPiG1iG2","s1.2.NSPiG1","s1.2.NSPiG2")
f5.2(a1, path="results1genes.sv", colnum=NULL)

a1 <- c("u.2.BCiH1iH2","u.2.BCiH1","u.2.BCiH2","u.2.NSPiG1iG2","u.2.NSPiG1","u.2.NSPiG2")
f5.2(a1, path="results1genes.joined", colnum=NULL)
a1 <- c("u.2.BCuniIH1iH2","u.2.BCuniIH1","u.2.BCuniIH2")
f5.2(a1, path="results1genes.joined1", colnum=NULL)

a1 <- c("u.3.BCuniIH1iH2","u.3.BCuniIH1","u.3.BCuniIH2","u.3.NSPiG1iG2","u.3.NSPiG1","u.3.NSPiG2")
f5.2(a1, path="results1genes.joined2", colnum=NULL)

# strip location
u.3.1.BCuniIH1iH2 <- f5.1(x=u.3.BCuniIH1iH2, strip=T, colNum=NULL)
u.3.1.BCuniIH1 <- f5.1(x=u.3.BCuniIH1, strip=T, colNum=NULL)
u.3.1.BCuniIH2 <- f5.1(x=u.3.BCuniIH2, strip=T, colNum=NULL)
u.3.1.NSPiG1iG2 <- f5.1(x=u.3.NSPiG1iG2, strip=T, colNum=NULL)
u.3.1.NSPiG1 <- f5.1(x=u.3.NSPiG1, strip=T, colNum=NULL)
u.3.1.NSPiG2 <- f5.1(x=u.3.NSPiG2, strip=T, colNum=NULL)


## E1-BC, E1-D
# gene name
u.2.E1iBC <- f2.1(x=u.E1, y=u.BC, idv=c(0,0), setfn="ic", repl="E1iBC")
u.2.E1iD <- f2.1(x=u.E1, y=u.D, idv=c(0,0), setfn="ic", repl="E1iD")
# E2-BC, E2-B2
u.2.E2iBC <- f2.1(x=u.E2, y=u.BC, idv=c(0,0), setfn="ic", repl="E1iBC")
u.2.E2iB2 <- f2.1(x=u.E2, y=u.B2, idv=c(0,0), setfn="ic", repl="E1iB2")
# E3-D, E3-B2
u.2.E3iD <- f2.1(x=u.E3, y=u.D, idv=c(0,0), setfn="ic", repl="E3iD")
u.2.E3iB2 <- f2.1(x=u.E3, y=u.B2, idv=c(0,0), setfn="ic", repl="E3iB2")

a1 <- c("u.2.E1iBC","u.2.E1iD","u.2.E2iBC","u.2.E2iB2","u.2.E3iD","u.2.E3iB2","u.E1","u.E2","u.E3","u.BC","u.D","u.B2")
stat.u.E <- f11(x=a1, setsize=2)
write.table(stat.u.E, file="results2/stat.u.E.txt", sep="\t")


# gene name + splice site aware
u.3.E1iBC <- f2.1(x=u2.E1, y=u2.BC, idv=c(0,0), setfn="ic", repl="E1iBC")
u.3.E1iD <- f2.1(x=u2.E1, y=u2.D, idv=c(0,0), setfn="ic", repl="E1iD")
# E2-BC, E2-B2
u.3.E2iBC <- f2.1(x=u2.E2, y=u2.BC, idv=c(0,0), setfn="ic", repl="E1iBC")
u.3.E2iB2 <- f2.1(x=u2.E2, y=u2.B2, idv=c(0,0), setfn="ic", repl="E1iB2")
# E3-D, E3-B2
u.3.E3iD <- f2.1(x=u2.E3, y=u2.D, idv=c(0,0), setfn="ic", repl="E3iD")
u.3.E3iB2 <- f2.1(x=u2.E3, y=u2.B2, idv=c(0,0), setfn="ic", repl="E3iB2")

save.image()


## export
a1 <- ls(pattern="^u\\.")
f5.2(a1, path="results1.u", colnum=NULL)






#### make  GOA  and p value calculations

# import GeneSCF lookup tables

scfd.goAll.entrez <- read.table(text=gsub("~", "\t", readLines(con="/home/korschi/geneSCFv1-1-p2/class/lib/db/goa_human/GO_all_gid.txt")),
		header=F, quote="", sep="\t", stringsAsFactors=F)
dimnames(scfd.goAll.entrez)[[2]] <- c("id","desc","entrez")
scfd.goAll.symbol <- read.table(text=gsub("~", "\t", readLines(con="/home/korschi/geneSCFv1-1-p2/class/lib/db/goa_human/GO_all_sym.txt")),
		header=F, quote="", sep="\t", stringsAsFactors=F)
dimnames(scfd.goAll.symbol)[[2]] <- c("id","desc","symbol")

scfd.reactom.entrez <- read.table(file="/home/korschi/geneSCFv1-1-p2/class/lib/db/Hs/REACTOME_gid.txt",
		header=F, quote="", sep="\t", stringsAsFactors=F)
scfd.reactom.entrez <- cbind(seq(1,nrow(scfd.reactom.entrez)), scfd.reactom.entrez)
dimnames(scfd.reactom.entrez)[[2]] <- c("id","desc","entrez")
scfd.reactom.symbol <- read.table(file="/home/korschi/geneSCFv1-1-p2/class/lib/db/Hs/REACTOME_sym.txt",
		header=F, quote="", sep="\t", stringsAsFactors=F)
scfd.reactom.symbol <- cbind(seq(1,nrow(scfd.reactom.symbol)), scfd.reactom.symbol)
dimnames(scfd.reactom.symbol)[[2]] <- c("id","desc","symbol")

scfd.ncg.entrez <- read.table(file="/home/korschi/geneSCFv1-1-p2/class/lib/db/Hs/NCG_gid.txt",
		header=F, quote="", sep="\t", stringsAsFactors=F)
scfd.ncg.entrez <- cbind(seq(1,nrow(scfd.ncg.entrez)), scfd.ncg.entrez)
dimnames(scfd.ncg.entrez)[[2]] <- c("id","desc","entrez")
scfd.ncg.symbol <- read.table(file="/home/korschi/geneSCFv1-1-p2/class/lib/db/Hs/NCG_sym.txt",
		header=F, quote="", sep="\t", stringsAsFactors=F)
scfd.ncg.symbol <- cbind(seq(1,nrow(scfd.ncg.symbol)), scfd.ncg.symbol)
dimnames(scfd.ncg.symbol)[[2]] <- c("id","desc","symbol")

scfd.kegg.entrez <- read.table(text=gsub("~", "\t", readLines(con="/home/korschi/geneSCFv1-1-p2/class/lib/db/hsa/kegg_database.txt")),
		header=F, quote="", sep="\t", stringsAsFactors=F)
dimnames(scfd.kegg.entrez)[[2]] <- c("id","desc","entrez")


# remove comma at the end of entries in db desc column
sum( grepl(pattern=",$", x=scfd.goAll.entrez[,"entrez"], perl=T) )	# 18430
scfd.goAll.entrez[,"entrez"] <- gsub(pattern=",$",replacement="",x=scfd.goAll.entrez[,"entrez"],perl=T)

sum( grepl(pattern=",$", x=scfd.goAll.symbol[,"symbol"], perl=T) )	# 18443
scfd.goAll.symbol[,"symbol"] <- gsub(pattern=",$",replacement="",x=scfd.goAll.symbol[,"symbol"],perl=T)

sum( grepl(pattern=",$", x=scfd.reactom.entrez[,"entrez"], perl=T) )	# 2379
scfd.reactom.entrez[,"entrez"] <- gsub(pattern=",$",replacement="",x=scfd.reactom.entrez[,"entrez"],perl=T)

sum( grepl(pattern=",$", x=scfd.reactom.symbol[,"symbol"], perl=T) )	# 0
#scfd.reactom.symbol[,"symbol"] <- gsub(pattern=",$",replacement="",x=scfd.reactom.symbol[,"symbol"],perl=T)

sum( grepl(pattern=",$", x=scfd.ncg.entrez[,"entrez"], perl=T) )	# 66
scfd.ncg.entrez[,"entrez"] <- gsub(pattern=",$",replacement="",x=scfd.ncg.entrez[,"entrez"],perl=T)

sum( grepl(pattern=",$", x=scfd.ncg.symbol[,"symbol"], perl=T) )	# 66
scfd.ncg.symbol[,"symbol"] <- gsub(pattern=",$",replacement="",x=scfd.ncg.symbol[,"symbol"],perl=T)

sum( grepl(pattern=",$", x=scfd.kegg.entrez[,"entrez"], perl=T) )	# 337
scfd.kegg.entrez[,"entrez"] <- gsub(pattern=",$",replacement="",x=scfd.kegg.entrez[,"entrez"],perl=T)

##
scfd.goAll.entrez
scfd.goAll.symbol
scfd.reactom.entrez
scfd.reactom.symbol
scfd.ncg.entrez
scfd.ncg.symbol
scfd.kegg.entrez

# change structure
scfd.goAll.entrez <- f8.2(scfd.goAll.entrez, num=T)
scfd.goAll.symbol <- f8.2(scfd.goAll.symbol, num=F)
scfd.reactom.entrez <- f8.2(scfd.reactom.entrez, num=T)
scfd.reactom.symbol <- f8.2(scfd.reactom.symbol, num=F)
scfd.ncg.entrez <- f8.2(scfd.ncg.entrez, num=T)
scfd.ncg.symbol <- f8.2(scfd.ncg.symbol, num=F)
scfd.kegg.entrez <- f8.2(scfd.kegg.entrez, num=T)

# create stat 1 scf
#															unique g.	groups
scfd.goAll.entrez.s1 %<-% f8.2.1(scfd.goAll.entrez)			# 	19364	18443
scfd.goAll.symbol.s1 <- f8.2.1(scfd.goAll.symbol)			# 	19692	18443
scfd.reactom.entrez.s1 %<-% f8.2.1(scfd.reactom.entrez)		# 	10803	 2400
scfd.reactom.symbol.s1 %<-% f8.2.1(scfd.reactom.symbol)		# 	11195	 2400
scfd.ncg.entrez.s1 %<-% f8.2.1(scfd.ncg.entrez)				#    1876	   66
scfd.ncg.symbol.s1 %<-% f8.2.1(scfd.ncg.symbol)				#  	 1920	   66
scfd.kegg.entrez.s1 %<-% f8.2.1(scfd.kegg.entrez)			#  	 8048	  337

# we will use only : scfd.goAll.symbol.s1
save.image()





#### all in one GOA  (based on GO tables from GeneSCF software)
library(future)
availableCores()	# system 12
plan(multicore)
# exit future mode:  end session (!)

# sv sets
# basic
#a <- f8.4(x=scfd.goAll.symbol.s1, y=s1.BC, df=F)


ba.BC %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.BC, df=F)
ba.D %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.D, df=F)
ba.B2 %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.B2, df=F)

ba.G1iG2 %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.G1iG2, df=F)
ba.H1iH2 %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.H1iH2, df=F)
ba.G1unique %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.G1unique, df=F)
ba.G2unique %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.G2unique, df=F)
ba.H1unique %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.H1unique, df=F)
ba.H2unique %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.H2unique, df=F)
ba.G1uniIH1uni %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.G1uniIH1uni, df=F)
ba.G2uniIH2uni %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.G2uniIH2uni, df=F)

ba.E1iE2iE3 %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.E1iE2iE3, df=F)
ba.E1unique %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.E1unique, df=F)
ba.E2unique %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.E2unique, df=F)
ba.E3unique %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.E3unique, df=F)

# core
ba.BCiDiB2 %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.BCiDiB2, df=F)
ba.BCunique %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.BCunique, df=F)
ba.B2unique %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.B2unique, df=F)
ba.Dunique %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.Dunique, df=F)

ba.msc %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.x.msc, df=F)
ba.nsp %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.x.nsp, df=F)
ba.sp %<-% f8.4(x=scfd.goAll.symbol.s1, y=s1.x.sp, df=F)
# 5 min future

# joined sets
# basic
bb.BC.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.BC, df=F)
bb.D.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.D, df=F)
bb.B2.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.B2, df=F)

bb.G1iG2.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.G1iG2, df=F)
bb.H1iH2.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.H1iH2, df=F)
bb.G1unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.G1unique, df=F)
bb.G2unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.G2unique, df=F)
bb.H1unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.H1unique, df=F)
bb.H2unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.H2unique, df=F)
bb.G1uniIH1uni.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.G1uniIH1uni, df=F)
bb.G2uniIH2uni.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.G2uniIH2uni, df=F)

bb.E1iE2iE3.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.E1iE2iE3, df=F)
bb.E1unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.E1unique, df=F)
bb.E2unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.E2unique, df=F)
bb.E3unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.E3unique, df=F)

# core
bb.BCiDiB2.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.BCiDiB2, df=F)
bb.BCunique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.BCunique, df=F)
bb.B2unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.B2unique, df=F)
bb.Dunique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.Dunique, df=F)

bb.msc.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.x.msc, df=F)
bb.nsp.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.x.nsp, df=F)
bb.sp.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.x.sp, df=F)

# ca. 5 min future - all 12 cores 100% - super fast (before ca. 1.1 h), RAM 3.4 GB up to 12 GB

# add on
bb.BCuniIH1iH2.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.3.1.BCuniIH1iH2, df=F)
bb.BCuniIH1.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.3.1.BCuniIH1, df=F)
bb.BCuniIH2.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.3.1.BCuniIH2, df=F)
bb.NSPiG1iG2.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.3.1.NSPiG1iG2, df=F)
bb.NSPiG1.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.3.1.NSPiG1, df=F)
bb.NSPiG2.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.3.1.NSPiG2, df=F)

bb.BCunique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.BCunique, df=F)
bb.B2unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.B2unique, df=F)
bb.Dunique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.Dunique, df=F)
bb.E1unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.E1unique, df=F)
bb.E2unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.E2unique, df=F)
bb.E3unique.joined %<-% f8.4(x=scfd.goAll.symbol.s1, y=u.E3unique, df=F)

save.image()


#### export some tables JC
# sv
# basic
f14(x=ba.BC, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.D, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.B2, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)

f14(x=ba.G1iG2, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.H1iH2, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.G1unique, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.G2unique, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.H1unique, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.H2unique, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.G1uniIH1uni, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.G2uniIH2uni, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)

f14(x=ba.E1iE2iE3, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.E1unique, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.E2unique, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.E3unique, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)

# core
f14(x=ba.BCiDiB2, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.BCunique, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.B2unique, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.Dunique, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)

f14(x=ba.msc, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.nsp, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)
f14(x=ba.sp, jcec=F, joined=F, path="results6GO_fdr/sv", fdr=0.05)

# joined
# basic
f14(x=bb.BC.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.D.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.B2.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)

f14(x=bb.G1iG2.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.H1iH2.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.G1unique.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.G2unique.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.H1unique.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.H2unique.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.G1uniIH1uni.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.G2uniIH2uni.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)

f14(x=bb.E1iE2iE3.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.E1unique.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.E2unique.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.E3unique.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)

# core
f14(x=bb.BCiDiB2.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.BCunique.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.B2unique.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.Dunique.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)

f14(x=bb.msc.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.nsp.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)
f14(x=bb.sp.joined, jcec=F, joined=T, path="results6GO_fdr/joined", fdr=0.05)

# add on
f14(x=bb.BCuniIH1iH2.joined, jcec=F, joined=T, path="results6GO_fdr/joined2", fdr=0.05)
f14(x=bb.BCuniIH1.joined, jcec=F, joined=T, path="results6GO_fdr/joined2", fdr=0.05)
f14(x=bb.BCuniIH2.joined, jcec=F, joined=T, path="results6GO_fdr/joined2", fdr=0.05)
f14(x=bb.NSPiG1iG2.joined, jcec=F, joined=T, path="results6GO_fdr/joined2", fdr=0.05)
f14(x=bb.NSPiG1.joined, jcec=F, joined=T, path="results6GO_fdr/joined2", fdr=0.05)
f14(x=bb.NSPiG2.joined, jcec=F, joined=T, path="results6GO_fdr/joined2", fdr=0.05)

save.image()


### export count tables
# number of GO per sample (JC,JEC) after GE  ( FDR < 0.05 )

a1 <- c("ba.B2unique", "ba.BCiDiB2", "ba.BCunique", "ba.Dunique", "ba.msc", "ba.nsp", "ba.sp")	# pick before from input structure
f11.3(names=a1, fdr=0.05, st=0, sf=0, jcec=T, id="core", path="results6counts")

a1 <- c("bb.B2unique.joined", "bb.BCiDiB2.joined", "bb.BCunique.joined", "bb.Dunique.joined", "bb.msc.joined", "bb.nsp.joined", "bb.sp.joined")
f11.3(names=a1, fdr=0.05, st=0, sf=0, jcec=T, id="core", path="results6counts")

a1 <- c("ba.B2","ba.BC","ba.D","ba.G1iG2","ba.G1uniIH1uni","ba.G1unique","ba.G2uniIH2uni","ba.G2unique","ba.H1iH2","ba.H1unique","ba.H2unique","ba.E1iE2iE3","ba.E1unique","ba.E2unique","ba.E3unique")
f11.3(names=a1, fdr=0.05, st=0, sf=0, jcec=T, id="basic", path="results6counts")

a1 <- c("bb.B2.joined","bb.BC.joined","bb.D.joined","bb.G1iG2.joined","bb.G1uniIH1uni.joined","bb.G1unique.joined","bb.G2uniIH2uni.joined","bb.G2unique.joined",
		"bb.H1iH2.joined","bb.H1unique.joined","bb.H2unique.joined","bb.E1iE2iE3.joined","bb.E1unique.joined","bb.E2unique.joined","bb.E3unique.joined")
f11.3(names=a1, fdr=0.05, st=0, sf=0, jcec=T, id="basic", path="results6counts")


a1 <- c("bb.BCuniIH1iH2.joined","bb.BCuniIH1.joined","bb.BCuniIH2.joined","bb.NSPiG1iG2.joined","bb.NSPiG1.joined","bb.NSPiG2.joined")
f11.3(names=a1, fdr=0.05, st=0, sf=0, jcec=F, id="EWspec", path="results6counts")




###  Visualization of GO terms
a <- date()
for(i in 1:2){
a1 <- c("ba.sp","ba.nsp","ba.msc","ba.BCunique","ba.B2unique","ba.Dunique")
f17.go(a1, jcec=F, path="results8visGO", fname=paste("core1-",i,sep=""), orgdb="org.Hs.eg.db", method="Rel", threshold=0.7, fontsize=6, min.freq=i)

a1 <- c("bb.sp.joined","bb.nsp.joined","bb.msc.joined","bb.BCunique.joined","bb.B2unique.joined","bb.Dunique.joined")
f17.go(a1, jcec=F, path="results8visGO", fname=paste("core2-",i,sep=""), orgdb="org.Hs.eg.db", method="Rel", threshold=0.7, fontsize=6, min.freq=i)

a1 <- c("bb.NSPiG1.joined","bb.NSPiG2.joined","bb.BCuniIH1.joined","bb.BCuniIH2.joined")
f17.go(a1, jcec=F, path="results8visGO", fname=paste("ewing-",i,sep=""), orgdb="org.Hs.eg.db", method="Rel", threshold=0.7, fontsize=6, min.freq=i)

a1 <- c("bb.BCunique.joined","bb.B2unique.joined","bb.Dunique.joined","bb.E1unique.joined","bb.E2unique.joined","bb.E3unique.joined")
f17.go(a1, jcec=F, path="results8visGO", fname=paste("E-control-",i,sep=""), orgdb="org.Hs.eg.db", method="Rel", threshold=0.7, fontsize=6, min.freq=i)
}
a; date()	# 2 h

# different image order
a <- date()
a1 <- c("ba.sp","ba.nsp","ba.msc","ba.BCunique","ba.B2unique","ba.Dunique")
f17b.go(a1, jcec=F, path="results9visGO", fname="core1", orgdb="org.Hs.eg.db", method="Rel", threshold=0.7, fontsize=6, min.freq=2)

a1 <- c("bb.sp.joined","bb.nsp.joined","bb.msc.joined","bb.BCunique.joined","bb.B2unique.joined","bb.Dunique.joined")
f17b.go(a1, jcec=F, path="results9visGO", fname="core2", orgdb="org.Hs.eg.db", method="Rel", threshold=0.7, fontsize=6, min.freq=2)

a1 <- c("bb.NSPiG1.joined","bb.NSPiG2.joined","bb.BCuniIH1.joined","bb.BCuniIH2.joined")
f17b.go(a1, jcec=F, path="results9visGO", fname="ewing", orgdb="org.Hs.eg.db", method="Rel", threshold=0.7, fontsize=6, min.freq=2)

a1 <- c("bb.BCunique.joined","bb.B2unique.joined","bb.Dunique.joined","bb.E1unique.joined","bb.E2unique.joined","bb.E3unique.joined")
f17b.go(a1, jcec=F, path="results9visGO", fname="E-control", orgdb="org.Hs.eg.db", method="Rel", threshold=0.7, fontsize=6, min.freq=2)
a; date()	# 2 h 35 min


# test
a1 <- c("bb.sp.joined")
a <- f17b.go(a1, jcec=F, path="results9visGO", fname="tt", orgdb="org.Hs.eg.db", method="Rel", threshold=0.7, fontsize=6, min.freq=1)

save.image()



###  Visualization  -  splice types of the same comparison   -versus-   contained GO terms
###  "splice types cluster GO terms"
# ba (SV) sets based on : GO analysis

# compare GO terms of SP sv versus SP joined
# sp
a1 <- list(
		SE.JC=ba.sp$sp.SE.JC$frequency[,1],
		A5.JC=ba.sp$sp.A5.JC$frequency[,1],
		A3.JC=ba.sp$sp.A3.JC$frequency[,1],
		MX.JC=ba.sp$sp.MX.JC$frequency[,1],
		RI.JC=ba.sp$sp.RI.JC$frequency[,1],
		SE.JCEC=ba.sp$sp.SE.JEC$frequency[,1],
		A5.JCEC=ba.sp$sp.A5.JEC$frequency[,1],
		A3.JCEC=ba.sp$sp.A3.JEC$frequency[,1],
		MX.JCEC=ba.sp$sp.MX.JEC$frequency[,1],
		RI.JCEC=ba.sp$sp.RI.JEC$frequency[,1]
		)
a.ba.sp.jc.jec.common <- iu.set(a1, idv=rep(0,10), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.sp.jc.jec.common", color.u="green")

a1 <- list(
		SE.JCEC=ba.sp$sp.SE.JEC$frequency[,1],
		A5.JCEC=ba.sp$sp.A5.JEC$frequency[,1],
		A3.JCEC=ba.sp$sp.A3.JEC$frequency[,1],
		MX.JCEC=ba.sp$sp.MX.JEC$frequency[,1],
		RI.JCEC=ba.sp$sp.RI.JEC$frequency[,1]
		)
a.ba.sp.jec.common <- iu.set(a1, idv=rep(0,5), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.sp.jec.common", color.u="green")

a1 <- list(
		SE.JC=ba.sp$sp.SE.JC$frequency[,1],
		A5.JC=ba.sp$sp.A5.JC$frequency[,1],
		A3.JC=ba.sp$sp.A3.JC$frequency[,1],
		MX.JC=ba.sp$sp.MX.JC$frequency[,1],
		RI.JC=ba.sp$sp.RI.JC$frequency[,1]
		)
a.ba.sp.jc.common <- iu.set(a1, idv=rep(0,5), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.sp.jc.common", color.u="green")
f16.png(x=a.set, path="results/", fname="a.ba.sp.jc.common", color.u="green")


# msc
a1 <- list(
		SE.JC=ba.msc$msc.SE.JC$frequency[,1],
		A5.JC=ba.msc$msc.A5.JC$frequency[,1],
		A3.JC=ba.msc$msc.A3.JC$frequency[,1],
		MX.JC=ba.msc$msc.MX.JC$frequency[,1],
		RI.JC=ba.msc$msc.RI.JC$frequency[,1],
		SE.JCEC=ba.msc$msc.SE.JEC$frequency[,1],
		A5.JCEC=ba.msc$msc.A5.JEC$frequency[,1],
		A3.JCEC=ba.msc$msc.A3.JEC$frequency[,1],
		MX.JCEC=ba.msc$msc.MX.JEC$frequency[,1],
		RI.JCEC=ba.msc$msc.RI.JEC$frequency[,1]
)
a.ba.msc.jc.jec.common <- iu.set(a1, idv=rep(0,10), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.msc.jc.jec.common", color.u="green")

a1 <- list(
		SE.JCEC=ba.msc$msc.SE.JEC$frequency[,1],
		A5.JCEC=ba.msc$msc.A5.JEC$frequency[,1],
		A3.JCEC=ba.msc$msc.A3.JEC$frequency[,1],
		MX.JCEC=ba.msc$msc.MX.JEC$frequency[,1],
		RI.JCEC=ba.msc$msc.RI.JEC$frequency[,1]
)
a.ba.msc.jec.common <- iu.set(a1, idv=rep(0,5), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.msc.jec.common", color.u="green")

a1 <- list(
		SE.JC=ba.msc$msc.SE.JC$frequency[,1],
		A5.JC=ba.msc$msc.A5.JC$frequency[,1],
		A3.JC=ba.msc$msc.A3.JC$frequency[,1],
		MX.JC=ba.msc$msc.MX.JC$frequency[,1],
		RI.JC=ba.msc$msc.RI.JC$frequency[,1]
)
a.ba.msc.jc.common <- iu.set(a1, idv=rep(0,5), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.msc.jc.common", color.u="green")

# nsp
a1 <- list(
		SE.JC=ba.nsp$nsp.SE.JC$frequency[,1],
		A5.JC=ba.nsp$nsp.A5.JC$frequency[,1],
		A3.JC=ba.nsp$nsp.A3.JC$frequency[,1],
		MX.JC=ba.nsp$nsp.MX.JC$frequency[,1],
		RI.JC=ba.nsp$nsp.RI.JC$frequency[,1],
		SE.JCEC=ba.nsp$nsp.SE.JEC$frequency[,1],
		A5.JCEC=ba.nsp$nsp.A5.JEC$frequency[,1],
		A3.JCEC=ba.nsp$nsp.A3.JEC$frequency[,1],
		MX.JCEC=ba.nsp$nsp.MX.JEC$frequency[,1],
		RI.JCEC=ba.nsp$nsp.RI.JEC$frequency[,1]
)
a.ba.nsp.jc.jec.common <- iu.set(a1, idv=rep(0,10), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.nsp.jc.jec.common", color.u="green")

a1 <- list(
		SE.JCEC=ba.nsp$nsp.SE.JEC$frequency[,1],
		A5.JCEC=ba.nsp$nsp.A5.JEC$frequency[,1],
		A3.JCEC=ba.nsp$nsp.A3.JEC$frequency[,1],
		MX.JCEC=ba.nsp$nsp.MX.JEC$frequency[,1],
		RI.JCEC=ba.nsp$nsp.RI.JEC$frequency[,1]
)
a.ba.nsp.jec.common <- iu.set(a1, idv=rep(0,5), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.nsp.jec.common", color.u="green")

a1 <- list(
		SE.JC=ba.nsp$nsp.SE.JC$frequency[,1],
		A5.JC=ba.nsp$nsp.A5.JC$frequency[,1],
		A3.JC=ba.nsp$nsp.A3.JC$frequency[,1],
		MX.JC=ba.nsp$nsp.MX.JC$frequency[,1],
		RI.JC=ba.nsp$nsp.RI.JC$frequency[,1]
)
a.ba.nsp.jc.common <- iu.set(a1, idv=rep(0,5), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.nsp.jc.common", color.u="green")


#### cross comparison e.g. SP - MSC
# msc-sp
a1 <- list(
		SE.JC.sp=ba.sp$sp.SE.JC$frequency[,1],
		A5.JC.sp=ba.sp$sp.A5.JC$frequency[,1],
		A3.JC.sp=ba.sp$sp.A3.JC$frequency[,1],
		MX.JC.sp=ba.sp$sp.MX.JC$frequency[,1],
		RI.JC.sp=ba.sp$sp.RI.JC$frequency[,1],
		SE.JC.msc=ba.msc$msc.SE.JC$frequency[,1],
		A5.JC.msc=ba.msc$msc.A5.JC$frequency[,1],
		A3.JC.msc=ba.msc$msc.A3.JC$frequency[,1],
		MX.JC.msc=ba.msc$msc.MX.JC$frequency[,1],
		RI.JC.msc=ba.msc$msc.RI.JC$frequency[,1]
)
a.ba.sp.msc.jc.common <- iu.set(a1, idv=rep(0,10), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.sp.msc.jc.common", color.u="green")
f16.png(x=a.set, path="results/", fname="a.ba.sp.msc.jc.common", color.u="green")

# msc-nsp  -- cross
a1 <- list(
		SE.JC.nsp=ba.nsp$nsp.SE.JC$frequency[,1],
		A5.JC.nsp=ba.nsp$nsp.A5.JC$frequency[,1],
		A3.JC.nsp=ba.nsp$nsp.A3.JC$frequency[,1],
		MX.JC.nsp=ba.nsp$nsp.MX.JC$frequency[,1],
		RI.JC.nsp=ba.nsp$nsp.RI.JC$frequency[,1],
		SE.JC.msc=ba.msc$msc.SE.JC$frequency[,1],
		A5.JC.msc=ba.msc$msc.A5.JC$frequency[,1],
		A3.JC.msc=ba.msc$msc.A3.JC$frequency[,1],
		MX.JC.msc=ba.msc$msc.MX.JC$frequency[,1],
		RI.JC.msc=ba.msc$msc.RI.JC$frequency[,1]
)
a.ba.nsp.msc.jc.common <- iu.set(a1, idv=rep(0,10), setfn="ic", raw=T)

f16(x=a.set, path="results/", fname="a.ba.nsp.msc.jc.common", color.u="green")

save.image()




### compare GO terms

###
a1 <- c("bb.msc.joined", "bb.nsp.joined", "bb.sp.joined")
a3.bb.sp.nsp.msc.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0   GO overlap

a1 <- c("bb.msc.joined", "bb.sp.joined")
a3.bb.sp.msc.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 4
a1 <- c("bb.msc.joined", "bb.nsp.joined")
a3.bb.nsp.msc.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0
a1 <- c("bb.sp.joined", "bb.nsp.joined")
a3.bb.sp.nsp.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0

###
a1 <- c("bb.B2unique.joined", "bb.BCunique.joined", "bb.Dunique.joined")
a3.bb.B2unique.BCunique.Dunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0

a1 <- c("bb.B2unique.joined", "bb.BCunique.joined")
a3.bb.B2unique.BCunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0
a1 <- c("bb.B2unique.joined", "bb.Dunique.joined")
a3.bb.B2unique.Dunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 19  D' - B2' own a common direction to msc
a1 <- c("bb.BCunique.joined", "bb.Dunique.joined")
a3.bb.BCunique.Dunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0

a1 <- c("bb.B2.joined", "bb.BC.joined", "bb.D.joined")
a3.bb.B2.BC.D.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 3

a1 <- c("bb.B2.joined", "bb.BC.joined")
a3.bb.B2.BC.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 3
a1 <- c("bb.B2.joined", "bb.D.joined")
a3.bb.B2.D.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 42  D + B2 own a common direction to msc
a1 <- c("bb.BC.joined", "bb.D.joined")
a3.bb.BC.D.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 3

###
a1 <- c("bb.E1unique.joined", "bb.BCunique.joined", "bb.Dunique.joined")
a3.bb.E1unique.BCunique.Dunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0
a1 <- c("bb.E2unique.joined", "bb.BCunique.joined", "bb.B2unique.joined")
a3.bb.E2unique.BCunique.B2unique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0
a1 <- c("bb.E3unique.joined", "bb.B2unique.joined", "bb.Dunique.joined")
a3.bb.E3unique.B2unique.Dunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 1

a1 <- c("bb.E1unique.joined", "bb.BCunique.joined")
a3.bb.E1unique.BCunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0
a1 <- c("bb.E1unique.joined", "bb.Dunique.joined")
a3.bb.E1unique.Dunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 18  E1'-D'

a1 <- c("bb.E2unique.joined", "bb.BCunique.joined")
a3.bb.E2unique.BCunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0
a1 <- c("bb.E2unique.joined", "bb.B2unique.joined")
a3.bb.E2unique.B2unique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 36  E2'-B2'

a1 <- c("bb.E3unique.joined", "bb.B2unique.joined")
a3.bb.E3unique.B2unique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 1
a1 <- c("bb.E3unique.joined", "bb.Dunique.joined")
a3.bb.E3unique.Dunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 1

###
a1 <- c("bb.G1unique.joined", "bb.G2unique.joined", "bb.nsp.joined")
a3.bb.G1unique.G2unique.nsp.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 2

a1 <- c("bb.G1unique.joined", "bb.nsp.joined")
a3.bb.G1unique.nsp.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 3
a1 <- c("bb.G2unique.joined", "bb.nsp.joined")
a3.bb.G2unique.nsp.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 2
a1 <- c("bb.G1unique.joined", "bb.G2unique.joined")
a3.bb.G1unique.G2unique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 20

a1 <- c("bb.H1unique.joined", "bb.H2unique.joined", "bb.BCunique.joined")
a3.bb.H1unique.H2unique.BCunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0

a1 <- c("bb.H1unique.joined", "bb.BCunique.joined")
a3.bb.H1unique.BCunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0
a1 <- c("bb.H2unique.joined", "bb.BCunique.joined")
a3.bb.H2unique.BCunique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 0
a1 <- c("bb.H1unique.joined", "bb.H2unique.joined")
a3.bb.H1unique.H2unique.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 29

a1 <- c("bb.G1uniIH1uni.joined", "bb.G2uniIH2uni.joined")
a3.bb.G1uniIH1uni.joined.G2uniIH2uni.joined.ic <- f15.2(x=a1, jcec=F, anno=scfd.goAll.symbol.s1$anno, setfn="ic", fdr=0.05)
# 13



###
a1 <- c("a3.bb.sp.msc.ic")
f15.3(x=a1, path="results7GOintersec/set_bb.sp.nsp.msc")

a1 <- c("a3.bb.B2unique.Dunique.ic","a3.bb.B2.BC.D.ic","a3.bb.B2.D.ic")
f15.3(x=a1, path="results7GOintersec/set_bb.B2.BC.D")

a1 <- c("a3.bb.E3unique.B2unique.Dunique.ic","a3.bb.E1unique.Dunique.ic","a3.bb.E2unique.B2unique.ic","a3.bb.E3unique.Dunique.ic")
f15.3(x=a1, path="results7GOintersec/set_bb.E")

a1 <- c("a3.bb.G1unique.nsp.ic","a3.bb.G2unique.nsp.ic","a3.bb.G1unique.G2unique.ic","a3.bb.G1uniIH1uni.joined.G2uniIH2uni.joined.ic")
f15.3(x=a1, path="results7GOintersec/set_bb.G.H")


			




#### GOA for protein complexes
# CORUM tables
CORUM.splice <- read.table(file="protein_complex_CORUM/spliceComplexes.txt", header=T, sep="\t", dec=".", stringsAsFactors=F)

#CORUM.core <- read.table(file="protein_complex_CORUM/coreComplexes.txt", header=T, sep="\t", dec=".", stringsAsFactors=F)		# errror: 175, nrows=174
# solved by open in LibreOffice, saved as csv, strings quoted in the csv format
CORUM.core <- read.table(file="protein_complex_CORUM/coreComplexes.csv", header=T, sep="\t", dec=".", stringsAsFactors=F)

#install.packages("jsonlite")
#library(jsonlite)
#CORUM.core <- fromJSON("protein_complex_CORUM/coreComplexes.json", flatten=F)

names(CORUM.core)
#[1]  "ComplexID"                           "ComplexName"                        
#[3]  "Organism"                            "Synonyms"                           
#[5]  "Cell.line"                           "subunits.UniProt.IDs."              
#[7]  "subunits.Entrez.IDs."                "Protein.complex.purification.method"
#[9]  "GO.ID"                               "GO.description"                     
#[11] "FunCat.ID"                           "FunCat.description"                 
#[13] "subunits.Gene.name.syn."             "Complex.comment"                    
#[15] "Disease.comment"                     "SWISSPROT.organism"                 
#[17] "Subunits.comment"                    "subunits.Gene.name."                
#[19] "PubMed.ID"                           "subunits.Protein.name."             


# analyze & correct inconsistencies in the CORUM.core table manually

# analyze space / multispace
sum( grepl(pattern=" +", x=CORUM.core[,"subunits.Gene.name."], fixed=F,perl=T) )		# 28 / 3612
CORUM.core[ grepl(pattern=" +", x=CORUM.core[,"subunits.Gene.name."], fixed=F,perl=T), "subunits.Gene.name."]

sum( grepl(pattern=" +", x=CORUM.core[,"subunits.Gene.name.syn."], fixed=F,perl=T) )	# 2190 / 3512
CORUM.core[ grepl(pattern=" +", x=CORUM.core[,"subunits.Gene.name.syn."], fixed=F,perl=T), "subunits.Gene.name.syn."][1:20]

# subunits.Gene.name.     all blanks to semicolon
sum( grepl(pattern=" ", x=CORUM.core[,"subunits.Gene.name."], fixed=T) )	# 28 / 3512
CORUM.core[,"subunits.Gene.name."] <- gsub(pattern=" ",replacement=";",x=CORUM.core[,"subunits.Gene.name."],perl=T)

sum( grepl(pattern="None", x=CORUM.core[,"subunits.Gene.name."], perl=T) )	# 1
CORUM.core[,"subunits.Gene.name."] <- gsub(pattern="None",replacement="",x=CORUM.core[,"subunits.Gene.name."],perl=T)

sum( grepl(pattern=";;", x=CORUM.core[,"subunits.Gene.name."], fixed=T) )	# 41
CORUM.core[,"subunits.Gene.name."] <- gsub(pattern=";;",replacement=";",x=CORUM.core[,"subunits.Gene.name."],perl=T)

sum( grepl(pattern="^;", x=CORUM.core[,"subunits.Gene.name."], perl=T) )	# 1
CORUM.core[,"subunits.Gene.name."] <- gsub(pattern="^;",replacement="",x=CORUM.core[,"subunits.Gene.name."],perl=T)

sum( grepl(pattern=";$", x=CORUM.core[,"subunits.Gene.name."], perl=T) )	# 2
CORUM.core[,"subunits.Gene.name."] <- gsub(pattern=";$",replacement="",x=CORUM.core[,"subunits.Gene.name."],perl=T)


# subunits.Gene.name.syn.     all blanks to semicolon
sum( grepl(pattern="None", x=CORUM.core[,"subunits.Gene.name.syn."], perl=T) )	# 1845
CORUM.core[,"subunits.Gene.name.syn."] <- gsub(pattern="None",replacement="",x=CORUM.core[,"subunits.Gene.name.syn."],perl=T)

sum( grepl(pattern=" ", x=CORUM.core[,"subunits.Gene.name.syn."], fixed=T) )	# 2190 / 3512
CORUM.core[,"subunits.Gene.name.syn."] <- gsub(pattern=" ",replacement=";",x=CORUM.core[,"subunits.Gene.name.syn."],perl=T)

sum( grepl(pattern=",", x=CORUM.core[,"subunits.Gene.name.syn."], fixed=T) )	# 1548
CORUM.core[,"subunits.Gene.name.syn."] <- gsub(pattern=",",replacement=";",x=CORUM.core[,"subunits.Gene.name.syn."],perl=T)

sum( grepl(pattern=";;", x=CORUM.core[,"subunits.Gene.name.syn."], fixed=T) )	# 2027		do multiple times
CORUM.core[,"subunits.Gene.name.syn."] <- gsub(pattern=";;",replacement=";",x=CORUM.core[,"subunits.Gene.name.syn."],perl=T)

sum( grepl(pattern="^;", x=CORUM.core[,"subunits.Gene.name.syn."], perl=T) )	# 1060
CORUM.core[,"subunits.Gene.name.syn."] <- gsub(pattern="^;",replacement="",x=CORUM.core[,"subunits.Gene.name.syn."],perl=T)

sum( grepl(pattern=";$", x=CORUM.core[,"subunits.Gene.name.syn."], perl=T) )	# 817
CORUM.core[,"subunits.Gene.name.syn."] <- gsub(pattern=";$",replacement="",x=CORUM.core[,"subunits.Gene.name.syn."],perl=T)

#
CORUM.core.hu <-  CORUM.core[CORUM.core[,"Organism"]=="Human", ]	# human  2417 / 3512

CORUM.core.hu.syn <-  CORUM.core.hu[ !(CORUM.core.hu[,"subunits.Gene.name.syn."]=="") , ]	# empty  115 / 2417
# 2302

#CORUM.core.hu.n <-  CORUM.core.hu[ !(CORUM.core.hu[,"subunits.Gene.name."]=="") , ]	# empty 0  / 2417


#

library(future)
availableCores()	# system 12
plan(multicore)

# sv sets in the view of complexes
# basic cx.B.old <- cx.B
cx.B %<-% f7.1(x=CORUM.core.hu, y=s.B, geneCol="subunits.Gene.name.", df=T)
cx.C1 %<-% f7.1(x=CORUM.core.hu, y=s.C1, geneCol="subunits.Gene.name.", df=T)
cx.C2 %<-% f7.1(x=CORUM.core.hu, y=s.C2, geneCol="subunits.Gene.name.", df=T)
cx.G1 %<-% f7.1(x=CORUM.core.hu, y=s.G1, geneCol="subunits.Gene.name.", df=T)
cx.G2 %<-% f7.1(x=CORUM.core.hu, y=s.G2, geneCol="subunits.Gene.name.", df=T)
cx.H1 %<-% f7.1(x=CORUM.core.hu, y=s.H1, geneCol="subunits.Gene.name.", df=T)
cx.H2 %<-% f7.1(x=CORUM.core.hu, y=s.H2, geneCol="subunits.Gene.name.", df=T)
cx.E1 %<-% f7.1(x=CORUM.core.hu, y=s.E1, geneCol="subunits.Gene.name.", df=T)
cx.E2 %<-% f7.1(x=CORUM.core.hu, y=s.E2, geneCol="subunits.Gene.name.", df=T)
cx.E3 %<-% f7.1(x=CORUM.core.hu, y=s.E3, geneCol="subunits.Gene.name.", df=T)

cx.BC %<-% f7.1(x=CORUM.core.hu, y=s.BC, geneCol="subunits.Gene.name.", df=F)
cx.D %<-% f7.1(x=CORUM.core.hu, y=s.D, geneCol="subunits.Gene.name.", df=T)
cx.B2 %<-% f7.1(x=CORUM.core.hu, y=s.B2, geneCol="subunits.Gene.name.", df=T)

cx.G1iG2 %<-% f7.1(x=CORUM.core.hu, y=s.G1iG2, geneCol="subunits.Gene.name.", df=F)
cx.H1iH2 %<-% f7.1(x=CORUM.core.hu, y=s.H1iH2, geneCol="subunits.Gene.name.", df=F)
cx.G1unique %<-% f7.1(x=CORUM.core.hu, y=s.G1unique, geneCol="subunits.Gene.name.", df=F)
cx.G2unique %<-% f7.1(x=CORUM.core.hu, y=s.G2unique, geneCol="subunits.Gene.name.", df=F)
cx.H1unique %<-% f7.1(x=CORUM.core.hu, y=s.H1unique, geneCol="subunits.Gene.name.", df=F)
cx.H2unique %<-% f7.1(x=CORUM.core.hu, y=s.H2unique, geneCol="subunits.Gene.name.", df=F)
cx.G1uniIH1uni %<-% f7.1(x=CORUM.core.hu, y=s.G1uniIH1uni, geneCol="subunits.Gene.name.", df=F)
cx.G2uniIH2uni %<-% f7.1(x=CORUM.core.hu, y=s.G2uniIH2uni, geneCol="subunits.Gene.name.", df=F)

cx.E1iE2iE3 %<-% f7.1(x=CORUM.core.hu, y=s.E1iE2iE3, geneCol="subunits.Gene.name.", df=F)
cx.E1unique %<-% f7.1(x=CORUM.core.hu, y=s.E1unique, geneCol="subunits.Gene.name.", df=F)
cx.E2unique %<-% f7.1(x=CORUM.core.hu, y=s.E2unique, geneCol="subunits.Gene.name.", df=F)
cx.E3unique %<-% f7.1(x=CORUM.core.hu, y=s.E3unique, geneCol="subunits.Gene.name.", df=F)

# core
cx.BCiDiB2 %<-% f7.1(x=CORUM.core.hu, y=s.BCiDiB2, geneCol="subunits.Gene.name.", df=F)
cx.BCunique %<-% f7.1(x=CORUM.core.hu, y=s.BCunique, geneCol="subunits.Gene.name.", df=F)
cx.B2unique %<-% f7.1(x=CORUM.core.hu, y=s.B2unique, geneCol="subunits.Gene.name.", df=F)
cx.Dunique %<-% f7.1(x=CORUM.core.hu, y=s.Dunique, geneCol="subunits.Gene.name.", df=F)

cx.msc %<-% f7.1(x=CORUM.core.hu, y=s.x.msc, geneCol="subunits.Gene.name.", df=F)
cx.nsp %<-% f7.1(x=CORUM.core.hu, y=s.x.nsp, geneCol="subunits.Gene.name.", df=F)
cx.sp %<-% f7.1(x=CORUM.core.hu, y=s.x.sp, geneCol="subunits.Gene.name.", df=F)


# joined sets in the view of complexes
# basic
cx.BC.joined %<-% f7.1(x=CORUM.core.hu, y=u.BC, geneCol="subunits.Gene.name.", df=F)
cx.D.joined %<-% f7.1(x=CORUM.core.hu, y=u.D, geneCol="subunits.Gene.name.", df=F)
cx.B2.joined %<-% f7.1(x=CORUM.core.hu, y=u.B2, geneCol="subunits.Gene.name.", df=F)

cx.G1iG2.joined %<-% f7.1(x=CORUM.core.hu, y=u.G1iG2, geneCol="subunits.Gene.name.", df=F)
cx.H1iH2.joined %<-% f7.1(x=CORUM.core.hu, y=u.H1iH2, geneCol="subunits.Gene.name.", df=F)
cx.G1unique.joined %<-% f7.1(x=CORUM.core.hu, y=u.G1unique, geneCol="subunits.Gene.name.", df=F)
cx.G2unique.joined %<-% f7.1(x=CORUM.core.hu, y=u.G2unique, geneCol="subunits.Gene.name.", df=F)
cx.H1unique.joined %<-% f7.1(x=CORUM.core.hu, y=u.H1unique, geneCol="subunits.Gene.name.", df=F)
cx.H2unique.joined %<-% f7.1(x=CORUM.core.hu, y=u.H2unique, geneCol="subunits.Gene.name.", df=F)
cx.G1uniIH1uni.joined %<-% f7.1(x=CORUM.core.hu, y=u.G1uniIH1uni, geneCol="subunits.Gene.name.", df=F)
cx.G2uniIH2uni.joined %<-% f7.1(x=CORUM.core.hu, y=u.G2uniIH2uni, geneCol="subunits.Gene.name.", df=F)

cx.E1iE2iE3.joined %<-% f7.1(x=CORUM.core.hu, y=u.E1iE2iE3, geneCol="subunits.Gene.name.", df=F)
cx.E1unique.joined %<-% f7.1(x=CORUM.core.hu, y=u.E1unique, geneCol="subunits.Gene.name.", df=F)
cx.E2unique.joined %<-% f7.1(x=CORUM.core.hu, y=u.E2unique, geneCol="subunits.Gene.name.", df=F)
cx.E3unique.joined %<-% f7.1(x=CORUM.core.hu, y=u.E3unique, geneCol="subunits.Gene.name.", df=F)

# core
cx.BCiDiB2.joined %<-% f7.1(x=CORUM.core.hu, y=u.BCiDiB2, geneCol="subunits.Gene.name.", df=F)
cx.BCunique.joined %<-% f7.1(x=CORUM.core.hu, y=u.BCunique, geneCol="subunits.Gene.name.", df=F)
cx.B2unique.joined %<-% f7.1(x=CORUM.core.hu, y=u.B2unique, geneCol="subunits.Gene.name.", df=F)
cx.Dunique.joined %<-% f7.1(x=CORUM.core.hu, y=u.Dunique, geneCol="subunits.Gene.name.", df=F)

cx.msc.joined %<-% f7.1(x=CORUM.core.hu, y=u.x.msc, geneCol="subunits.Gene.name.", df=F)
cx.nsp.joined %<-% f7.1(x=CORUM.core.hu, y=u.x.nsp, geneCol="subunits.Gene.name.", df=F)
cx.sp.joined %<-% f7.1(x=CORUM.core.hu, y=u.x.sp, geneCol="subunits.Gene.name.", df=F)

# ca. 10 min - all 12 cores 100% - super fast (before ca. 1 h)

# addon
cx.BCuniIH1iH2.joined %<-% f7.1(x=CORUM.core.hu, y=u.3.1.BCuniIH1iH2, geneCol="subunits.Gene.name.", df=F)
cx.BCuniIH1.joined %<-% f7.1(x=CORUM.core.hu, y=u.3.1.BCuniIH1, geneCol="subunits.Gene.name.", df=F)
cx.BCuniIH2.joined %<-% f7.1(x=CORUM.core.hu, y=u.3.1.BCuniIH2, geneCol="subunits.Gene.name.", df=F)
cx.NSPiG1iG2.joined %<-% f7.1(x=CORUM.core.hu, y=u.3.1.NSPiG1iG2, geneCol="subunits.Gene.name.", df=F)
cx.NSPiG1.joined %<-% f7.1(x=CORUM.core.hu, y=u.3.1.NSPiG1, geneCol="subunits.Gene.name.", df=F)
cx.NSPiG2.joined %<-% f7.1(x=CORUM.core.hu, y=u.3.1.NSPiG2, geneCol="subunits.Gene.name.", df=F)

save.image()


#### export some tables JC
# sv
# basic
f13(x=cx.BC, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.D, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.B2, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)

f13(x=cx.G1iG2, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.H1iH2, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.G1unique, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.G2unique, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.H1unique, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.H2unique, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.G1uniIH1uni, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.G2uniIH2uni, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)

f13(x=cx.E1iE2iE3, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.E1unique, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.E2unique, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.E3unique, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)

# core
f13(x=cx.BCiDiB2, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.BCunique, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.B2unique, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.Dunique, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)

f13(x=cx.msc, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.nsp, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)
f13(x=cx.sp, jcec=F, joined=F, path="results5corum_fdr/sv", fdr=0.05)

# joined
# basic
f13(x=cx.BC.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.D.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.B2.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)

f13(x=cx.G1iG2.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.H1iH2.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.G1unique.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.G2unique.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.H1unique.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.H2unique.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.G1uniIH1uni.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.G2uniIH2uni.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)

f13(x=cx.E1iE2iE3.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.E1unique.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.E2unique.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.E3unique.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)

# core
f13(x=cx.BCiDiB2.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.BCunique.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.B2unique.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.Dunique.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)

f13(x=cx.msc.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.nsp.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)
f13(x=cx.sp.joined, jcec=F, joined=T, path="results5corum_fdr/joined", fdr=0.05)

# addon
f13(x=cx.BCuniIH1iH2.joined, jcec=F, joined=T, path="results5corum_fdr/joined2", fdr=0.05)
f13(x=cx.BCuniIH1.joined, jcec=F, joined=T, path="results5corum_fdr/joined2", fdr=0.05)
f13(x=cx.BCuniIH2.joined, jcec=F, joined=T, path="results5corum_fdr/joined2", fdr=0.05)
f13(x=cx.NSPiG1iG2.joined, jcec=F, joined=T, path="results5corum_fdr/joined2", fdr=0.05)
f13(x=cx.NSPiG1.joined, jcec=F, joined=T, path="results5corum_fdr/joined2", fdr=0.05)
f13(x=cx.NSPiG2.joined, jcec=F, joined=T, path="results5corum_fdr/joined2", fdr=0.05)

save.image()


# export counts     ( FDR < 0.05 )
a1 <- c("cx.B2unique", "cx.BCiDiB2", "cx.BCunique", "cx.Dunique", "cx.msc", "cx.nsp", "cx.sp")	# pick before from input structure
f11.3(names=a1, fdr=0.05, st=0, sf=0, jcec=T, id="core", path="results5counts")

a1 <- c("cx.B2unique.joined", "cx.BCiDiB2.joined", "cx.BCunique.joined", "cx.Dunique.joined", "cx.msc.joined", "cx.nsp.joined", "cx.sp.joined")
f11.3(names=a1, fdr=0.05, st=0, sf=0, jcec=T, id="core.j", path="results5counts")

a1 <- c("cx.B2","cx.BC","cx.D","cx.G1iG2","cx.G1uniIH1uni","cx.G1unique","cx.G2uniIH2uni","cx.G2unique","cx.H1iH2","cx.H1unique","cx.H2unique",
		"cx.E1iE2iE3","cx.E1unique","cx.E2unique","cx.E3unique")
f11.3(names=a1, fdr=0.05, st=0, sf=0, jcec=T, id="basic", path="results5counts")

a1 <- c("cx.B2.joined","cx.BC.joined","cx.D.joined","cx.G1iG2.joined","cx.G1uniIH1uni.joined","cx.G1unique.joined","cx.G2uniIH2uni.joined","cx.G2unique.joined",
		"cx.H1iH2.joined","cx.H1unique.joined","cx.H2unique.joined","cx.E1iE2iE3.joined","cx.E1unique.joined","cx.E2unique.joined","cx.E3unique.joined")
f11.3(names=a1, fdr=0.05, st=0, sf=0, jcec=T, id="basic.j", path="results5counts")


a1 <- c("cx.BCuniIH1iH2.joined","cx.BCuniIH1.joined","cx.BCuniIH2.joined","cx.NSPiG1iG2.joined","cx.NSPiG1.joined","cx.NSPiG2.joined")
f11.3(names=a1, fdr=0.05, st=0, sf=0, jcec=T, id="EWspec", path="results5counts")






#### plot genome distribution of splice variants - test

# attach 16q workspace
attach(what=".RD16q", name="16q")
# The following objects are masked _by_ .GlobalEnv:  ab, f2, i, SNP.envelope
cen.SNPdummy <- SNP.dummy
cen.tromere.human2 <- centromere.human
cen.ABI4.cytoband <- ABI4.cytoband
cen.gin <- Mapping10K.Xba131
cen.ginE <- ABI.HU4

sum( row.names(cen.ginE) == 20880 )
cen.ginE[paste(20880),"Gene.Symbol"]

detach(name="16q",unload=T,character.only=T)

save.image()





#### plot genome distribution of splice variants
# first create joined basic sets with full df

# f8.5(a1)	 obsolete

# filter by PSI
a1 <- c("c.s.C1","c.s.C2","c.s.B","c.s.B2","c.s.D","c.s.G1","c.s.G2","c.s.H1","c.s.H2","c.s.E1","c.s.E2","c.s.E3")
g.stat <- apply.PSI.filter(a1, s.col=c("PSI_sum_s1","PSI_sum_s2"), ext.struct="g", psi1=c(0.1,0.90), psi2=c(0.1,0.90), diff=c(0.5,0.90))
# g.s. created

# work
# names "exonStart_0base","exonEnd" not identical throughout -> take numbers
# JC
#a1 <- c("c.s.C1","c.s.C2","c.s.B","c.s.B2","c.s.D","c.s.G1","c.s.G2","c.s.H1","c.s.H2","c.s.E1","c.s.E2","c.s.E3")
#g.stat2 <- f18b(a1, prefix="genome_all_sv_JC", jc=T, path="results0genome", 
#		sel.cols=c(4,5,7,8),
#		color.anno.lines="black", z.id="symbol")
#
#g.stat3 <- f18b(a1, prefix="genome_all_sv_top_400_JC", jc=T, path="results0genome", 
#		sel.cols=c(4,5,7,8), sort.col="FDR", top=400,
#		color.anno.lines="black", z.id="symbol")

a1 <- c("g.s.B","g.s.B2","g.s.D","g.s.G1","g.s.G2","g.s.H1","g.s.H2","g.s.C1","g.s.C2","g.s.E1","g.s.E2","g.s.E3")
g.stat4 <- f18b(a1, prefix="genome_psi_sv_JC", jc=T, path="results0genome", 
		sel.cols=c(4,5,7,8),
		color.anno.lines="black", z.id="symbol")
a1 <- c("g.s.B","g.s.G1","g.s.G2","g.s.H1","g.s.H2")
g.stat4.1 <- f18c(a1, prefix="genome_psi_sv_JC_1", main="JC - B G1 G2 H1 H2", jc=T, path="results0genome", 
		sel.cols=c(4,5,7,8),
		color.anno.lines="black", z.id="symbol")

# JCEC
#a1 <- c("c.s.C1","c.s.C2","c.s.B","c.s.B2","c.s.D","c.s.G1","c.s.G2","c.s.H1","c.s.H2","c.s.E1","c.s.E2","c.s.E3")
#g.stat5 <- f18b(a1, prefix="genome_all_sv_JCEC", jc=F, path="results0genome", 
#		sel.cols=c(4,5,7,8),
#		color.anno.lines="black", z.id="symbol")
#
#g.stat6 <- f18b(a1, prefix="genome_all_sv_top_400_JCEC", jc=F, path="results0genome", 
#		sel.cols=c(4,5,7,8), sort.col="FDR", top=400,
#		color.anno.lines="black", z.id="symbol")

a1 <- c("g.s.B","g.s.B2","g.s.D","g.s.G1","g.s.G2","g.s.H1","g.s.H2","g.s.C1","g.s.C2","g.s.E1","g.s.E2","g.s.E3")
g.stat7 <- f18b(a1, prefix="genome_psi_sv_JCEC", jc=F, path="results0genome", 
		sel.cols=c(4,5,7,8),
		color.anno.lines="black", z.id="symbol")
a1 <- c("g.s.B","g.s.G1","g.s.G2","g.s.H1","g.s.H2")
g.stat7.1 <- f18c(a1, prefix="genome_psi_sv_JCEC_1", main="JCEC - B G1 G2 H1 H2", jc=F, path="results0genome", 
		sel.cols=c(4,5,7,8),
		color.anno.lines="black", z.id="symbol")


save.image()






#### compare to Nikhil data sets
# import
nde.42sp_nsp_i_nsp_msc <- read.table(file="data_nl/42sp_nsp_i_nsp_msc.txt", header=F, sep="\t", row.names=NULL, stringsAsFactor=F)
nde.312onco43 <- read.table(file="data_nl/312onco43.txt", header=F, sep="\t", row.names=NULL, stringsAsFactor=F)
nde.312sp_nsp <- read.table(file="data_nl/312sp_nsp.txt", header=F, sep="\t", row.names=NULL, stringsAsFactor=F)
# reimport customized
nde.u.3.BCuniIH1_JC <- read.table(file="data_nl/u.3.BCuniIH1_JC.txt", header=F, sep="\t", row.names=NULL, stringsAsFactor=F)
nde.u.3.BCuniIH2_JC <- read.table(file="data_nl/u.3.BCuniIH2_JC.txt", header=F, sep="\t", row.names=NULL, stringsAsFactor=F)
nde.u.3.NSPiG1_JC <- read.table(file="data_nl/u.3.NSPiG1_JC.txt", header=F, sep="\t", row.names=NULL, stringsAsFactor=F)
nde.u.3.NSPiG2_JC <- read.table(file="data_nl/u.3.NSPiG2_JC.txt", header=F, sep="\t", row.names=NULL, stringsAsFactor=F)

## intersection 312 w/ Ewing sets
nde.n312.nBCH1 <- iu.set(x=list(n312=nde.312sp_nsp, nBCH1=nde.u.3.BCuniIH1_JC), idv=c(1,1), setfn="ic", m.out=NULL)
# 0
nde.n312.nBCH2 <- iu.set(x=list(n312=nde.312sp_nsp, nBCH2=nde.u.3.BCuniIH2_JC), idv=c(1,1), setfn="ic", m.out=NULL)
# 0
nde.n312.nNSPG1 <- iu.set(x=list(n312=nde.312sp_nsp, nBCH2=nde.u.3.NSPiG1_JC), idv=c(1,1), setfn="ic", m.out=NULL)
# 1  LMO7
nde.n312.nNSPG2 <- iu.set(x=list(n312=nde.312sp_nsp, nBCH2=nde.u.3.NSPiG2_JC), idv=c(1,1), setfn="ic", m.out=NULL)
# 2  LMO7 SELENBP1

nde.n43.nBCH1 <- iu.set(x=list(n43=nde.312onco43, nBCH1=nde.u.3.BCuniIH1_JC), idv=c(1,1), setfn="ic", m.out=NULL)
# 0
nde.n43.nBCH2 <- iu.set(x=list(n43=nde.312onco43, nBCH2=nde.u.3.BCuniIH2_JC), idv=c(1,1), setfn="ic", m.out=NULL)
# 0
nde.n43.nNSPG1 <- iu.set(x=list(n43=nde.312onco43, nBCH2=nde.u.3.NSPiG1_JC), idv=c(1,1), setfn="ic", m.out=NULL)
# 0
nde.n43.nNSPG2 <- iu.set(x=list(n43=nde.312onco43, nBCH2=nde.u.3.NSPiG2_JC), idv=c(1,1), setfn="ic", m.out=NULL)
# 1  SELENBP1    oncogene, but here?

## BC
nde.n312.nBC <- iu.set(x=list(n312=nde.312sp_nsp, nBCH2=u.BC$all_splice_ty_JC), idv=c(1,0), setfn="ic", m.out=NULL)
# 6  CDKN3 E2F5 EPC1 LMO7 SELENBP1 TXNDC11

nde.n43.nBC <- iu.set(x=list(n43=nde.312onco43, nBCH2=u.BC$all_splice_ty_JC), idv=c(1,0), setfn="ic", m.out=NULL)
# 3  CDKN3 E2F5 SELENBP1    all three oncogenes

## BCunique
nde.n312.BCuni <- iu.set(x=list(n312=nde.312sp_nsp, nBCH2=u.BCunique$all_splice_ty_JC), idv=c(1,0), setfn="ic", m.out=NULL)
# 3  CDKN3 E2F5 EPC1
nde.n312.nsp <- iu.set(x=list(n312=nde.312sp_nsp, nBCH2=u.x.nsp$all_splice_ty_JC), idv=c(1,0), setfn="ic", m.out=NULL)
# 2  LMO7 SELENBP1
nde.n312.sp <- iu.set(x=list(n312=nde.312sp_nsp, nBCH2=u.x.sp$all_splice_ty_JC), idv=c(1,0), setfn="ic", m.out=NULL)
# 1  TXNDC11

nde.n43.BCuni <- iu.set(x=list(n43=nde.312onco43, nBCH2=u.BCunique$all_splice_ty_JC), idv=c(1,0), setfn="ic", m.out=NULL)
# 2  CDKN3 E2F5
nde.n43.nsp <- iu.set(x=list(n43=nde.312onco43, nBCH2=u.x.nsp$all_splice_ty_JC), idv=c(1,0), setfn="ic", m.out=NULL)
# 1  SELENBP1
nde.n43.sp <- iu.set(x=list(n43=nde.312onco43, nBCH2=u.x.sp$all_splice_ty_JC), idv=c(1,0), setfn="ic", m.out=NULL)
# 0

## 43 onco - 42 csc
nde.n43onco.42csc <- iu.set(x=list(n43=nde.312onco43, nBCH2=nde.42sp_nsp_i_nsp_msc), idv=c(1,0), setfn="ic", m.out=NULL)
# 0






#### find certain genes in the sets
a1 <- ls(pattern="^s1\\.")
a2 <- c("^EWS","^ERG","^FLI")
search.s1.set01 <- find.gene.names(x=a1, query=a2, jcec=F, sel.col=1)
write.table(search.s1.set01, file="results3search/search.s1.set01.EWS.ERG.FLI.txt", quote=F, sep="\t", row.names=F, col.names=T)

a1 <- ls(pattern="^s\\.")
a2 <- c("^EWS","^ERG","^FLI")
search.s.set02 <- find.gene.names(x=a1, query=a2, jcec=F, sel.col=1)
write.table(search.s.set02, file="results3search/search.s.set02.EWS.ERG.FLI.txt", quote=F, sep="\t", row.names=F, col.names=T)

a1 <- ls(pattern="^u\\.")
a2 <- c("^EWS","^ERG","^FLI")
search.u.set03 <- find.gene.names(x=a1, query=a2, jcec=F, sel.col=1)
write.table(search.u.set03, file="results3search/search.u.set03.EWS.ERG.FLI.txt", quote=F, sep="\t", row.names=F, col.names=T)

a1 <- ls(pattern="^u2\\.")
a2 <- c("^EWS","^ERG","^FLI")
search.u2.set04 <- find.gene.names(x=a1, query=a2, jcec=F, sel.col=1)
write.table(search.u2.set04, file="results3search/search.u2.set04.EWS.ERG.FLI.txt", quote=F, sep="\t", row.names=F, col.names=T)

#
a1 <- ls(pattern="^s\\.")
a2 <- c("^ACADVL","^LMO7","^NOP58","^POLDIP3","^RMDN1","^SMARCB1","^TM7SF3","^TSPAN3")
search.s.set05 <- find.gene.names(x=a1, query=a2, jcec=F, sel.col=1)
write.table(search.s.set05, file="results3search/search.s.set05.nsp.g1.txt", quote=F, sep="\t", row.names=F, col.names=T)
a2 <- c("^AC022826.2","^ACADVL","^LMO7","^NOP58","^SELENBP1","^TM7SF3","^TSPAN3","^ZFAND1","^ZNF283")
search.s.set06 <- find.gene.names(x=a1, query=a2, jcec=F, sel.col=1)
write.table(search.s.set06, file="results3search/search.s.set06.nsp.g2.txt", quote=F, sep="\t", row.names=F, col.names=T)
a2 <- c("^ATP13A3","^EPB41","^HLCS","^OGT","^POC5","^SNHG17","^TCAIM","^TRA2A")
search.s.set07 <- find.gene.names(x=a1, query=a2, jcec=F, sel.col=1)
write.table(search.s.set07, file="results3search/search.s.set07.BCunique.h1.txt", quote=F, sep="\t", row.names=F, col.names=T)
a2 <- c("^EPB41","^KMO","^SNHG1","^SNHG17","^STRADA","^TRDMT1")
search.s.set08 <- find.gene.names(x=a1, query=a2, jcec=F, sel.col=1)
write.table(search.s.set08, file="results3search/search.s.set08.BCunique.h2.txt", quote=F, sep="\t", row.names=F, col.names=T)


#
a1 <- ls(pattern="^s\\.")
a2 <- c("^GATA6","^TRPC4","^FLG","^TGM2", "^SCA1","^CD29","^CD44","^CD90")
# Genes to Cells  (2009)14,  407-424
# Stem Cell Research, Volume 8, Issue 1, January 2012, Pages 58-73
search.s.set09 <- find.gene.names(x=a1, query=a2, jcec=F, sel.col=1)
write.table(search.s.set09, file="results3search/search.s.set09.msc_spec.txt", quote=F, sep="\t", row.names=F, col.names=T)

# universal search
a1 <- ls(pattern="^u\\.")
a1 <- ls(pattern="^s\\.")
a1 <- ls(pattern="^s1\\.")
a <- find.gene.names(a1, query=c("^PAX7","^RUNX2"), jcec=F, sel.col=1)


#####  for the discussion
# nature: Aberrant RNA splicing in cancer; expression changes and driver mutations of splicing factor genes
a1 <- c("s.B","s.B2","s.D","s.C1","s.C2","s.G1","s.G2","s.H1","s.H2","s.E1","s.E2","s.E3")
# list from figure 1b
a2 <- c("VEGFA","BCL2L1","CD44","RAC1")		# n1
search.n1 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 9
# list from figure 2
a2 <- c("BIRC5","BCL2L1","CASP2","CASP8","CASP9","CFLAR","MCL1","MDM2","TP53")		# n2
search.n2 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 29
a2 <- c("GLS","LDHC","MAX","PFKFB3","PKM")
search.n3 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 11
a2 <- c("AR","BRAF","CCND1","EGFR","FGFR2","HRAS","KRAS","PTEN","RAC1")
search.n4 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 265
a2 <- c("AIMP2","ANXA7","BIN1","RB1","TP53")
search.n5 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 6
a2 <- c("CEACAM1","HLA-G","IL7")
search.n6 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 0
a2 <- c("TERT")
search.n7 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 0
a2 <- c("CD44","IRF3","PPARA","RAC1","STAT3")
search.n8 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 1
a2 <- c("CD44","CD82","CDH11","CTTN","ENHA","FGFR2","FAM3B","KLF6","MST1R","RAC1","TNC")
search.n9 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 6
a2 <- c("FN1","VEGFA")
search.n10 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 43
a2 <- c("MLH1","MRE11A","RAC1")		# n11
search.n11 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 2

write.table(search.n1, file="results3search/search.n1.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.n2, file="results3search/search.n2.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.n3, file="results3search/search.n3.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.n4, file="results3search/search.n4.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.n5, file="results3search/search.n5.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.n6, file="results3search/search.n6.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.n7, file="results3search/search.n7.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.n8, file="results3search/search.n8.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.n9, file="results3search/search.n9.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.n10, file="results3search/search.n10.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.n11, file="results3search/search.n11.txt", quote=F, sep="\t", row.names=F, col.names=T)


# Toretsky 10 ARID1A, RUNX2, EZH2, TERT, CUL4A, CAV3, CALD1, HDAC8, USP2, IGFBP3
# fully gain or lose an isoform or demonstrate alternative promoter selection based on the modulation of EWS-FLI1 expression
# 9 RUNX1, MBNL1, DACT3, DHX29, CDKN1C, CCND1, DCP2, BRF1, DIDO1
# whereas 9 genes did not demonstrate changes consistent with annotated isoforms
#
#Retained Introns and Skipped Exons Are Altered by EWS-FLI1.
#Other splicing events—mutually exclusive exons (MXE), alternative 5′ splice site (A5SS), and alternative 3′ splice site
#(A3SS)—did not demonstrate consistent changes between conditions nor did they have the same magnitude as the increase in
#retained introns (Fig. 3A).
#
# YK-4-279 Alters Splicing Rather than Direct Transcriptional Inhibition
#
#Before the data presented in this paper, TERT, CLK1, CASP3, and PPFIBP1 were not recognized as isoforms modulated by EWS-FLI1.
a1 <- c("s.B","s.B2","s.D","s.C1","s.C2","s.G1","s.G2","s.H1","s.H2","s.E1","s.E2","s.E3")
a2 <- c("ARID1A","RUNX2","EZH2","TERT","CUL4A","CAV3","CALD1","HDAC8","USP2","IGFBP3")	# 1) 10 validated , Selvanathan
search.t1 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 17
a2 <- c("RUNX1","MBNL1","DACT3","DHX29","CDKN1C","CCND1","DCP2","BRF1","DIDO1")	# 9 not validated , Selvanathan
search.t2 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 14
a2 <- c("TERT","CLK1","CASP3","PPFIBP1")	# 4 in abstract
search.t3 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 20
a2 <- c("ARID1A","BAF250a","SMARCF1")		# 4) 2019 publ.		all alias to ARID1A
search.t4 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 0
# BAF complex members / limited
a2 <- c("ARID1A","ACTL6B","ACTL6A","SMARCA2","SMARCA4","ACTB","ACTG1","SMARCB1","ARID1B","SMARCC2","SMARCC1","SMARCE1","SMARCD1")
search.t5.baf.members <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 39
# BAF complex members / all
a2 <- c("SMARCA4","SMARCC1","SMARCD1","SMARCD2","SMARCD3","BCL7A","BCL7B","BCL7C","ACTL6A","ACTL6B","ACTB",		# BAF PBAF ncBAF   Harrod et al.
		"SMARCC2","SMARCB1","SMARCE1",																		# BAF PBAF
		"ARID1A","ARID1B","DPF1","DPF2","DPF3",															# BAF
		"SMARCA2","SS18","SS18L1",																	# BAF ncBAF
		"ARID2","PHF10","PBRM1","BRD7",															# PBAF
		"BICRA","BICRAL","BRD9")															# ncBAF
search.t6.baf.all <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 55

write.table(search.t1, file="results3search/search.t1.10.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.t2, file="results3search/search.t2.9.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.t3, file="results3search/search.t3.4.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.t5.baf.members, file="results3search/search.t5.baf.members.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.t6.baf.all, file="results3search/search.t6.baf.all.txt", quote=F, sep="\t", row.names=F, col.names=T)

# how many BAF members in CORUM database
a <- grepl(pattern="BAF", x=CORUM.core.hu[,"ComplexName"], ignore.case=T)
CORUM.core.hu[a,"ComplexName"]
a3 <- CORUM.core.hu[a,]
search.BAF.genes.1 <- a3[c(2,6,11), "subunits.Gene.name."]
search.BAF.g_syn.1 <- a3[c(2,6,11), "subunits.Gene.name.syn."]
write.table(a3[c(2,6,11),], file="results3search/search.t4.0baf.txt", quote=F, sep="\t", row.names=F, col.names=T)

# again genes2BAF, by CORUM
a3[c(2,6,11),c(1:3)]
#      ComplexID               ComplexName Organism
# 125        189               BAF complex    Human
# 928       1237               BAF complex    Human
# 2287      6147 BAFL-BAF-LAP2beta complex    Human

a1 <- c("cx.B","cx.B2","cx.D","cx.C1","cx.C2","cx.G1","cx.G2","cx.H1","cx.H2","cx.E1","cx.E2","cx.E3")
a2 <- c("189","1237","6147")		# 
search.t4.a <- find.gene2complex.cx(a1, query=a2, jcec=F, prefix="BAF")	# 65

write.table(search.t4.a, file="results3search/search.t4.genes2baf.txt", quote=F, sep="\t", row.names=F, col.names=T)



a1 <- c("s.B","s.B2","s.D","s.C1","s.C2","s.G1","s.G2","s.H1","s.H2","s.E1","s.E2","s.E3")
# Hu-Lieskovan
a2 <- c("AK3","ARHGEF1","ARHH","ATF5","ATP1A1","C6orf9","CAV1","CAV2","CCBL1","CCK","CCND1","CD1E","CD79A","CD99","CDH11","CEBPB",
		"CES1","CHN2","CITED2","CRIP2","CSNK1E","CSPG5","CSRP1","DAPK1","DPYSL2","EGR2","FADS1","FCGRT","FLJ14547","FNBP1",
		"FOS","FVT1","G0S2","GABARAPL1","GLCE","GLG1","GPRK5","GYG2","HES1","HLA-E","HOXD9","ID2","IGFBP4","IL1RAP","IPO13",
		"JAK1","KIAA0746","KIAA0794","KIAA0893","LNK","LOH11CR2A","LY96","MAN2A2","MAPT","ME1","MGC27165","MSX1","MYC","MYO10",
		"Nbak2","NELL2","NPTXR","OLFM1","PFKP","PFTK1","PPFIA3","PRKCB1","PSEN1","PTPNS1","RAP1GA1","RCOR","RUNX3","SIAT1",
		"SLC1A4","SMA5","SMARCC1","SORD","STARD13","STAT6","STEAP","SYT1","TRIM2","UAP1","WNT5A","XPNPEP1","ZDHHC3","ZNF183")
search.hulieskovan <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)	# 104		old expression study

# 42set2up-SP.NSP-MSC.NSP
a2 <- c("ANK3","ATF1","CDK6","CRIM1","CTGF","CYR61","DUSP1","EBLN2","EPC1","FOS","FOSL2","HIST1H1C","HIST1H2BC","HIST1H3C",
		"HIST2H2AB","HIST2H2AC","ID1","JUN","KLF6","LMO7","LRIG3","LUZP1","MAPRE2","MIR222HG","NBPF10","POPDC3","RN7SKP160",
		"RN7SL107P","RNVU1-6","RNY3","SMAD7","SOCS5","STOM","TFPI2","TIPARP","TNIK","TRAM1","TXNDC11","TXNDC12","VMP1",
		"ZNF184","CH17-373J23.1")
search.42set2up <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)		# 21		delta SP MSC

# 312set1-sp-nsp
a2 <- c("ABCB1","AC058791.1","AC083843.1","ACTL6A","ADM2","AKR1C2","AL355075.1","ANK3","APOLD1","ARL6IP1","ASPM","ASS1","ATAD3C",
		"ATF1","ATG3","ATHL1","ATP11B","AURKA","AUTS2","BCYRN1","bP-21264C1.2","BRIX1","BUB1","BUB1B","C4orf48","CACNG8",
		"CAPN10-AS1","CAV1","CCNA2","CCNB1","CCNB2","CDC20","CDC25C","CDCA2","CDCA3","CDCA8","CDH17","CDK1","CDK6","CDKN2C",
		"CDKN3","CENPA","CENPE","CEP55","CEP85","CH17-373J23.1","CHCHD7","CKAP2L","CKS2","CLIP3","COPS3","CRIM1","CSE1L","CSRNP2",
		"CTD-2287O16.1","CTD-3222D19.8","CTGF","CTTNBP2","CXCL1","CYR61","DCLK1","DDX21","DEPDC1","DHRS11","DIMT1","DLEU2","DLGAP5",
		"DNAH8","DNAJC8","DPYSL3","DUSP1","E2F5","EBLN2","EEF1A1P5","ELMO1","ENPP2","EPC1","ERAP1","ERCC6L","FABP4","FABP5",
		"FAM64A","FAM72A","FAM83D","FOPNL","FOS","FOSB","FOSL2","FOXO1","FP236383.10","FTH1","GAS2L3","GNB3","GPSM2","HDAC9",
		"HES1","HIST1H1C","HIST1H2AE","HIST1H2AG","HIST1H2AK","HIST1H2AL","HIST1H2BB","HIST1H2BC","HIST1H2BF","HIST1H2BG",
		"HIST1H2BH","HIST1H2BI","HIST1H2BL","HIST1H2BN","HIST1H3B","HIST1H3C","HIST1H3G","HIST1H4D","HIST1H4H","HIST2H2AB",
		"HIST2H2AC","HJURP","HMGB2","HMMR","HSP90AA1","HSPH1","HYLS1","ID1","ID2","ISG15","JPH1","JUN","KBTBD2","KBTBD8",
		"KCNQ1OT1","KIF14","KIF18A","KIF20A","KIF23","KIF2C","KLF6","KNSTRN","KPNA2","LA16c-360H6.3","LDHA","LIN9","LINC00342",
		"LINC00685","LMO7","LRIG3","LRP1","LUZP1","LY6H","MAD2L1","MAPRE2","MEG3","MIAT","MIR222HG","MIR663AHG","MKX","MLC1",
		"MPP4","MSL2","MTCO2P22","MTND1P23","MTND2P28","MTND5P11","MTRNR2L13","MUC19","MYC","NBPF10","NCAPD3","NCAPH","NCOR2",
		"NDC1","NEAT1","NEK2","NOP16","NPAT","NPM1P5","NPW","NRIP1","NRXN3","NSDHL","NUF2","NUP35","NUSAP1","OBSCN","OIP5","P3H2",
		"PBK","PDZD7","PGM5P2","PLEKHF2","PLK1","PLXNA3","PNPT1","POPDC3","PRC1","PRPS1","PSRC1","PTPRD","PWWP2A","RACGAP1","RALGAPA2",
		"RANGAP1","RHOBTB3","RN7SKP160","RN7SKP9","RN7SL107P","RN7SL118P","RN7SL181P","RNF139-AS1","RNF26","RNU1-11P","RNU1-42P",
		"RNU1-77P","RNU11","RNU12","RNU4-2","RNU5A-1","RNU5B-1","RNU5E-1","RNVU1-17","RNVU1-6","RNY1","RNY1P13","RNY3","RORB",
		"RP1-34B20.21","RP11-113I24.1","RP11-178H8.7","RP11-303E16.2","RP11-332M2.1","RP11-334C17.5","RP11-438B23.2","RP11-481C4.2",
		"RP11-797A18.5","RP11-863K10.7","RP5-1198O20.4","RP5-875O13.1","RPL28","RPS24P8","RPS28","RPS6P25","RRM2","RRS1-AS1","RSBN1",
		"RUNDC3B","RYR1","SALL1","SAPCD2","SCARNA12","SCARNA8","SELENBP1","SETP14","SGK1","SGOL2","SKA3","SLC14A1","SLC25A17","SLC4A3",
		"SMAD7","SNHG25","SNORA28","SNORA38","SNORA53","SNORA66","SNORA71A","SNORD14E","SNORD17","SNORD3A","SNORD41","SNORD71","SOCS5",
		"SORD","SPAG5","SPRY4","STOM","SYT2","TBC1D4","TFPI2","TGFBI","TIPARP","TMEM97","TMPO","TMPO-AS1","TMX2","TNIK","TOP2A","TPX2",
		"TRAM1","TRIP13","TTK","TUBG1","TXNDC11","TXNDC12","U1","UBE2C","UBE2QL1","UBE2T","USP42","UTS2","VMP1","WDR20","WDR35","WDR43",
		"WDR97","ZBTB2","ZC3H12C","ZFX","ZNF143","ZNF184","ZNF267","ZNF367","ZNF480","ZNF789")
search.312set1 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)		# 290		delta SP NSP

# 43oncogenes-set1
a2 <- c("ASS1","ATF1","AURKA","CAV1","CCNB1","CCNB2","CDC25C","CDH17","CDK1","CDK6","CDKN2C","CDKN3","COPS3","CTGF","CXCL1","DLEU2","DUSP1",
		"E2F5","FAM72A","FAM83D","FOS","FOXO1","ID1","ID2","ISG15","JUN","KIF14","KLF6","LIN9","LRIG3","MEG3","MYC","NEAT1","PBK","PLK1",
		"PTPRD","SELENBP1","SGK1","SPRY4","TFPI2","TGFBI","UBE2C","UBE2QL1")
search.43oncoSet1 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)		# 81		subset

# 46set3down-SP.NSP-MSC.NSP		lncRNA : ENSG00000278932
a2 <- c("ADM2","AKR1C2","AUTS2","CACNG8","CAPN10-AS1","CAPS","CCDC136","CHCHD7","CTDP1","DNAH8","ELMO1","GNB3","KCNQ1OT1","LINC00342","LINC00685",
		"LY6H","MIAT","MIR663AHG","MTCO2P22","MTRNR2L13","MUC19","NACAD","NCOR2","NPW","OBSCN","PDZD7","PGM5P2","RALGAPA2","RNF139-AS1",
		"RORB","PRPF31","RPL28","RPS6P25","RRS1-AS1","RYR1","SELENBP1","SLC4A3","SNHG25","SNORD41","SYT2","ZNF789")
search.46set3down <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)		# 21		delta SP MSC

a <- unique( sapply(strsplit(search.hulieskovan[,1], split="_", fixed=T), function(x){ x[1] } ) )
length( a )		# 33
write.table(a, file="results3search/search.hulieskovan.uniq.txt", quote=F, sep="\t", row.names=F, col.names=T)
a <- unique( sapply(strsplit(search.42set2up[,1], split="_", fixed=T), function(x){ x[1] } ) )
length( a )		# 8
write.table(a, file="results3search/search.42set2up.uniq.txt", quote=F, sep="\t", row.names=F, col.names=T)
a <- unique( sapply(strsplit(search.312set1[,1], split="_", fixed=T), function(x){ x[1] } ) )
length( a )		# 76
write.table(a, file="results3search/search.312set1.uniq.txt", quote=F, sep="\t", row.names=F, col.names=T)
a <- unique( sapply(strsplit(search.43oncoSet1[,1], split="_", fixed=T), function(x){ x[1] } ) )
length( a )		# 22
write.table(a, file="results3search/search.43oncoSet1.uniq.txt", quote=F, sep="\t", row.names=F, col.names=T)
a <- unique( sapply(strsplit(search.46set3down[,1], split="_", fixed=T), function(x){ x[1] } ) )
length( a )		# 6
write.table(a, file="results3search/search.46set3down.uniq.txt", quote=F, sep="\t", row.names=F, col.names=T)

write.table(search.hulieskovan, file="results3search/search.hulieskovan.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.42set2up, file="results3search/search.42set2up.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.312set1, file="results3search/search.312set1.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.43oncoSet1, file="results3search/search.43oncoSet1.txt", quote=F, sep="\t", row.names=F, col.names=T)
write.table(search.46set3down, file="results3search/search.46set3down.txt", quote=F, sep="\t", row.names=F, col.names=T)


# cf. Hindawi review
a1 <- c("s.B","s.B2","s.D","s.C1","s.C2","s.G1","s.G2","s.H1","s.H2","s.E1","s.E2","s.E3")
a2 <- c("CCND1")
search.CCND1 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)		# 0

# STAT3
a2 <- c("STAT3")
search.STAT3 <- find.gene.names(a1, query=a2, jcec=F, sel.col=1)		# 0

# rev
a2 <- c("^SF1","^SNRPC")
search.SF1.SNRPC <- find.gene.names(x=a1, query=a2, jcec=F, sel.col=1)	# 0



save.image()




####  import -> customize -> export  rmats tables
# 
# /home/korschi/on2/rmats_ek/msc_hfb/A3SS.MATS.JC.txt

trim.rmats.raw.table(xp="/home/korschi/on2/rmats_ek", xout="/home/korschi/on2/rmats_ek_cust")





####    exon scheme
# EWSR1
# from-to:  29268268-29300521   length seq:  32254

pdf("EWSR1.pdf",width=11,height=7)
par(mfrow=c(2,1))
a <- gene.exon.illustration(file="EWSR1_Exons_ENST00000397938.csv", ze=1, lwd.s=3, lwd.m=3, genelabel="EWSR1", othertext="",
		posMarker=29287870, pmtype="s", lineMarker=NULL,
		col=c("blue","red","darkgreen","blue","orange3","black"), cexD=0.6, cexA=1)
a <- gene.exon.illustration(file="EWSR1_Exons_ENST00000397938.csv", ze=6, lwd.s=3, lwd.m=3, genelabel="EWSR1", othertext="",
		posMarker=29287870, pmtype="s", lineMarker=NULL,
		col=c("blue","red","darkgreen","blue","orange3","black"), cexD=0.6, cexA=1)
par(mfrow=c(1,1))
dev.off()

# hg19 c(29684828,29683890,29684210,29683363,29687600,29683162,29684719,29684818,29684642,29684492,29684308,29683472,29685344,29684045,29683597,29683670,29684170,29684319,29684120,29683936)

# ERG
# from-to:  38661780-38380030   length seq:  281751

pdf("ERG.pdf",width=11,height=7)
par(mfrow=c(2,1))
a <- gene.exon.illustration(file="ERG_Exons_ENST00000442448.csv", ze=1, lwd.s=3, lwd.m=3, genelabel="ERG", othertext="",
		posMarker=38397500, pmtype="s", lineMarker=NULL,
		col=c("blue","red","darkgreen","blue","orange3","black"), cexD=0.6, cexA=1)
a <- gene.exon.illustration(file="ERG_Exons_ENST00000442448.csv", ze=10, lwd.s=3, lwd.m=3, genelabel="ERG", othertext="",
		posMarker=38397500, pmtype="s", lineMarker=NULL,
		col=c("blue","red","darkgreen","blue","orange3","black"), cexD=0.6, cexA=1)
par(mfrow=c(1,1))
dev.off()

# hg19 c(39764323,39755802,39764341,39762917, 39758924)

# FLI1
# from-to:  128693916-128813266   length seq:  119351

pdf("FLI1.pdf",width=11,height=7)
par(mfrow=c(2,1))
a <- gene.exon.illustration(file="FLI1_Exons_ENST00000281428.csv", ze=1, lwd.s=3, lwd.m=3, genelabel="FLI1", othertext="",
		posMarker=128777471, pmtype="s", lineMarker=NULL,
		col=c("blue","red","darkgreen","blue","orange3","black"), cexD=0.6, cexA=1)
a <- gene.exon.illustration(file="FLI1_Exons_ENST00000281428.csv", ze=8, lwd.s=3, lwd.m=3, genelabel="FLI1", othertext="",
		posMarker=128777471, pmtype="s", lineMarker=NULL,
		col=c("blue","red","darkgreen","blue","orange3","black"), cexD=0.6, cexA=1)
par(mfrow=c(1,1))
dev.off()

# hg19 c(128660222,128672447,128648755,128647160,128677198,128670750,128667067,128657758,128678099,128649485,128670953,128659187,128678890,128669317,128675070,128644790,128656714,128656016,128674661)

#####

# TCAIM
# from-to	44338119-44407790	length seq: 69672
pdf("TCAIM.pdf",width=11,height=7)
par(mfrow=c(2,1))
a <- gene.exon.illustration(file="TCAIM_Exons_ENST00000417237.csv", ze=1, lwd.s=3, lwd.m=8, genelabel="TCAIM", othertext="",
		posMarker=NULL, pmtype="s", lineMarker=c(44367456,44367708),
		col=c("blue","red","darkgreen","blue","green","black"), cexD=0.6, cexA=1)
a <- gene.exon.illustration(file="TCAIM_Exons_ENST00000417237.csv", ze=8, lwd.s=3, lwd.m=8, genelabel="TCAIM", othertext="",
		posMarker=NULL, pmtype="s", lineMarker=c(44367456,44367708),
		col=c("blue","red","darkgreen","blue","green","black"), cexD=0.6, cexA=1)
par(mfrow=c(1,1))
dev.off()

# ACADVL
# from-to	7217125-7225266		length seq: 8142
pdf("ACADVL.pdf",width=11,height=7)
par(mfrow=c(2,1))
a <- gene.exon.illustration(file="ACADVL_Exons_ENST00000543245.csv", ze=1, lwd.s=3, lwd.m=8, genelabel="ACADVL", othertext="",
		posMarker=NULL, pmtype="s", lineMarker=c(7222667,7223237, 7223813,7224069),
		col=c("blue","red","darkgreen","blue","green","black"), cexD=0.6, cexA=1)
a <- gene.exon.illustration(file="ACADVL_Exons_ENST00000543245.csv", ze=2, lwd.s=3, lwd.m=8, genelabel="ACADVL", othertext="",
		posMarker=NULL, pmtype="s", lineMarker=c(7222667,7223237, 7223813,7224069),
		col=c("blue","red","darkgreen","blue","green","black"), cexD=0.6, cexA=1)
par(mfrow=c(1,1))
dev.off()

# TSPAN3
# from-to	77071109-77041404	length seq: 29706
pdf("TSPAN3.pdf",width=11,height=7)
par(mfrow=c(2,1))
a <- gene.exon.illustration(file="TSPAN3_Exons_ENST00000267970.csv", ze=1, lwd.s=3, lwd.m=8, genelabel="TSPAN3", othertext="",
		posMarker=NULL, pmtype="s", lineMarker=c(77056064,77056255, 77055789,77055863),
		col=c("blue","red","darkgreen","blue","green","black"), cexD=0.6, cexA=1)
a <- gene.exon.illustration(file="TSPAN3_Exons_ENST00000267970.csv", ze=2, lwd.s=3, lwd.m=8, genelabel="TSPAN3", othertext="",
		posMarker=NULL, pmtype="s", lineMarker=c(77056064,77056255, 77055789,77055863),
		col=c("blue","red","darkgreen","blue","green","black"), cexD=0.6, cexA=1)
par(mfrow=c(1,1))
dev.off()

# EPB41
# from-to	28914569-29120041	length seq: 205473
pdf("EPB41.pdf",width=11,height=7)
par(mfrow=c(2,1))
a <- gene.exon.illustration(file="EPB41_Exons_ENST00000343067.csv", ze=1, lwd.s=3, lwd.m=8, genelabel="EPB41", othertext="",
		posMarker=NULL, pmtype="s", lineMarker=c(29060422,29060484, 29058589,29058645),
		col=c("blue","red","darkgreen","blue","green","black"), cexD=0.6, cexA=1)
a <- gene.exon.illustration(file="EPB41_Exons_ENST00000343067.csv", ze=8, lwd.s=3, lwd.m=8, genelabel="EPB41", othertext="",
		posMarker=NULL, pmtype="s", lineMarker=c(29060422,29060484, 29058589,29058645),
		col=c("blue","red","darkgreen","blue","green","black"), cexD=0.6, cexA=1)
par(mfrow=c(1,1))
dev.off()


### details
# EWSR1
# from-to:  2926 8268-2930 0521   length seq:  32254

pdf("EWSR1_b.pdf",width=11,height=7)
par(mfrow=c(3,1))
a <- gene.exon.illustration(file="EWSR1_Exons_ENST00000397938.csv", ze=1, lwd.s=3, lwd.m=3, genelabel="EWSR1", othertext="",
		posMarker=29287870, pmtype="s", lineMarker=c(29275629,29287106, 29298733,29299279),
		col=c("blue","red","darkgreen","blue","orange3","black"), cexD=0.6, cexA=1.1)
a <- gene.exon.illustration(file="EWSR1_Exons_ENST00000397938.csv", ze=6, lwd.s=3, lwd.m=3, genelabel="EWSR1", othertext="",
		posMarker=29287870, pmtype="s", lineMarker=c(29275629,29287106, 29298733,29299279),
		col=c("blue","red","darkgreen","blue","orange3","black"), cexD=0.6, cexA=1.1)
par(mfrow=c(1,1))
dev.off()




####   stat block   --   joined & sv
# number of splice events per splice variant before GOA
a1 <- ls(pattern="^u\\.")
stat.sv.u <- f11(x=a1, setsize=2)
write.table(stat.sv.u, file="results2/stat.sv.u.txt", sep="\t")

a1 <- ls(pattern="^s\\.")
stat.sv.s <- f11(x=a1, setsize=10)
write.table(stat.sv.s, file="results2/stat.sv.s.txt", sep="\t")

a1 <- ls(pattern="^s1\\.")
stat.sv.s1 <- f11(x=a1, setsize=10)
write.table(stat.sv.s1, file="results2/stat.sv.s1.txt", sep="\t")






#### some further details ####
save.image()


# extract Table 5 information
a1 <- c("s.B")
info.BC.H1 <- find.gene.information(a1,
		query=c("ATP13A3", "HLCS", "OGT", "POC5", "TCAIM", "TRA2A"),
		position=c(194412198, 36947332, 71536177, 75707736, 44367455, 23521706),
		jcec=F)
a1 <- c("s.B")
info.BC.H2 <- find.gene.information(a1,
		query=c("KMO", "SNHG1", "STRADA", "TRDMT1"),
		position=c(241590011, 62851987, 63728333, 17161482),
		jcec=F)
a1 <- c("s.B")
info.BC.H <- find.gene.information(a1,
		query=c("EPB41", "SNHG17"),
		position=c(29058588, 38422091),
		jcec=F)
a1 <- c("s.B")
info.NSP.G1 <- find.gene.information(a1,
		query=c("POLDIP3", "RMDN1", "SMARCB1"),
		position=c(42601969, 86472348, 23791755),
		jcec=F)
a1 <- c("s.B")
info.NSP.G2 <- find.gene.information(a1,
		query=c("AC022826.2", "SELENBP1", "ZFAND1", "ZNF283"),
		position=c(73825146, 151369003, 81721226, 43837052),
		jcec=F)
a1 <- c("s.B")
info.NSP.G <- find.gene.information(a1,
		query=c("ACADVL", "LMO7", "NOP58", "TM7SF3", "TSPAN3"),
		position=c(7223812, 75835151, 202278211, 27003235, 77055788),
		jcec=F)

info.BC.NSP <- rbind(info.BC.H1, info.BC.H2, info.BC.H, info.NSP.G1, info.NSP.G2, info.NSP.G)

write.table(info.BC.NSP, file="00_info.tab5.tsv", sep="\t", row.names=T, col.names=T)




# expression from DE (previous publication)

# import raw
de.raw.p1 <- read.table("/home/korschi/Desktop/counts_nik/counts_raw.txt", header=T, sep="\t", dec=".", stringsAsFactors=F)

# import DE data (normalized: edgeR TMM)
de.norm.p1 <- read.table("/home/korschi/Desktop/counts_nik/counts_norm.txt", header=T, sep="\t", dec=".", stringsAsFactors=F)

names(de.norm.p1) <- c("SP1","SP2","SP3","NSP1","NSP2","NSP3","nst1","nst2","nst3","nso1","nso2","nso3","hFIB1","hFIB2","hFIB3","hFIB4","MSC1","MSC2","MSC3","MSC4","ES1","ES2")
length(c("SP1","SP2","SP3","NSP1","NSP2","NSP3","nst1","nst2","nst3","nso1","nso2","nso3","hFIB1","hFIB2","hFIB3","hFIB4","MSC1","MSC2","MSC3","MSC4","ES1","ES2"))
# 22

#
#par(mar=c(7,5,1,1))
de.norm.p1.log2 <- log2(de.norm.p1)

pdf("de_all_exp_TMM.pdf", width=7, height=4.5)
boxplot(de.norm.p1, main="DE TMM norm", las=2, outline=F)		# de_all...
boxplot(de.norm.p1.log2, main="DE TMM norm log2", las=2, outline=F)
dev.off()



#
library(pheatmap)
# all experiments
de.corMat <- cor(de.norm.p1, use="c")		# argument use="c" : error if there are any missing data points

# annotation
sampleInfo <- data.frame(
		group=c("SP","SP","SP","NSP","NSP","NSP","nst","nst","nst","nso","nso","nso","hFIB","hFIB","hFIB","hFIB","MSC","MSC","MSC","MSC","ES","ES"),
		sample=c("SP1","SP2","SP3","NSP1","NSP2","NSP3","nst1","nst2","nst3","nso1","nso2","nso3","hFIB1","hFIB2","hFIB3","hFIB4","MSC1","MSC2","MSC3","MSC4","ES1","ES2"),
		stringsAsFactors=F)
rownames(sampleInfo) <- sampleInfo[,2]

rownames(sampleInfo)
dimnames(de.corMat)

pdf("de_all_exp_PearsonCor_heat.pdf", width=7, height=5.8)
pheatmap(de.corMat, main="DE Pearson cor")
pheatmap(de.corMat, main="DE Pearson cor", annotation_col=sampleInfo[,1,drop=F])		# de_all...
dev.off()

# select
# tab5
de.nsp.g1 <- c("POLDIP3", "RMDN1", "SMARCB1") # NSP i G1
de.nsp.g2 <- c("SELENBP1", "ZFAND1", "ZNF283") # NSP i G2		# "AC022826.2": paralog: UBE2W, even not in the raw data..., annotation changed in-between... ?
de.nsp.gc <- c("ACADVL", "LMO7", "NOP58", "TM7SF3", "TSPAN3") # NSP i G common

de.bcuni.h1 <- c("ATP13A3", "HLCS", "OGT", "POC5", "TCAIM", "TRA2A") # SP i H1
de.bcuni.h2 <- c("KMO", "SNHG1", "STRADA", "TRDMT1") # SP i H2
de.bcuni.hc <- c("EPB41", "SNHG17") # SP i H common

de.nsp.bcuni.all <- c(de.nsp.g1,de.nsp.g2,de.nsp.gc, de.bcuni.h1,de.bcuni.h2,de.bcuni.hc)

#
de.norm.p1.sub1 <- de.norm.p1[de.nsp.bcuni.all,]

sum(de.norm.p1.sub1==0)
range(de.norm.p1.sub1)	# 0 2805934
de.norm.p1.sub1[de.norm.p1.sub1==0] <- 0.1
de.norm.p1.sub1.log2 <- log2(de.norm.p1.sub1)
range(de.norm.p1.sub1.log2)	# -3.3 21.4
de.norm.p1.sub2.log2 <- de.norm.p1.sub1.log2 + 3.4

de.corMat.sub1.a <- cor(de.norm.p1.sub1, use="c")
de.corMat.sub1.b <- cor(t(de.norm.p1.sub1), use="c")

# unicode is working inside but not to PDF

anno.row <- data.frame(
		set=c(rep("NSP' \u2229 G1",3),rep("NSP' \u2229 G2",3),rep("NSP' \u2229 G overlap",5),rep("BC' \u2229 H1",6),rep("BC' \u2229 H2",4),rep("BC' \u2229 H overlap",2)),
		gene=de.nsp.bcuni.all,
		stringsAsFactors=F)
rownames(anno.row) <- anno.row[,2]

pdf("de_sub1_PearsonCor_heat_c.pdf", width=7, height=5)#, fonts="OpenSymbol")					# de_sub1...
pheatmap(de.norm.p1.sub1, main="DE sub", cluster_cols=F, cluster_rows=F, annotation_col=sampleInfo[,1,drop=F])
pheatmap(de.norm.p1.sub1.log2, main="DE sub log2", cluster_cols=F, cluster_rows=F, annotation_col=sampleInfo[,1,drop=F])
pheatmap(de.norm.p1.sub1.log2, main="DE sub log2", cluster_cols=F, cluster_rows=F, annotation_row=anno.row[,1,drop=F])
pheatmap(de.norm.p1.sub1.log2, main="DE sub log2", cluster_cols=F, cluster_rows=F, annotation_col=sampleInfo[,1,drop=F], annotation_row=anno.row[,1,drop=F])
pheatmap(de.corMat.sub1.a, main="DE sub Samples Pearson cor", annotation_col=sampleInfo[,1,drop=F])
pheatmap(de.corMat.sub1.b, main="DE sub DS genes Pearson cor", annotation_col=anno.row[,1,drop=F])
pheatmap(de.norm.p1.sub2.log2, main="DE log2 sub Samples Pearson cor", cluster_cols=T, cluster_rows=F, clustering_distance_cols="correlation", annotation_col=sampleInfo[,1,drop=F], annotation_row=anno.row[,1,drop=F])
pheatmap(de.norm.p1.sub2.log2, main="DE log2 sub Samples Pearson cor", cluster_cols=T, cluster_rows=T, clustering_distance_rows="correlation", clustering_distance_cols="correlation", annotation_col=sampleInfo[,1,drop=F], annotation_row=anno.row[,1,drop=F])
dev.off() #


# DE expression for further genes
####
# CD133=PROM1, POU5F1=OCT4, CD99 Ewing marker
a1 <- c("PROM1","NANOG", "MYC","KLF4","LIN28A")		# not part "SOX2" alias "OCT4"

# Amaral etal 2014 - EWS strong : CD99, ENG(CD105), THY1(CD90),  weak : CD34, PTPRC(CD45)
#					MSC-EWS cell separation: (CD99), CD14, NGFR(CD271), KIT(CD117)
a2 <- c("CD99","ENG","THY1","CD34")		# not part "PTPRC"
a3 <- c("CD14","NGFR","KIT")
a1 <- c(a1,a2,a3)

de.norm.p1.sub1 <- de.norm.p1[a1,]

sum(de.norm.p1.sub1==0)	# 17
range(de.norm.p1.sub1)	# 0 44936
de.norm.p1.sub1[de.norm.p1.sub1==0] <- 0.1
de.norm.p1.sub1.log2 <- log2(de.norm.p1.sub1)
range(de.norm.p1.sub1.log2)	# -3.3 15.4
de.norm.p1.sub2.log2 <- de.norm.p1.sub1.log2 + 3.4

anno.row <- data.frame(
		set=c(rep("MSC features",5),rep("EwS features",4),rep("EwS-MSC segregation",3)),
		gene=row.names(de.norm.p1.sub1),
		stringsAsFactors=F)
rownames(anno.row) <- anno.row[,2]

anno.col <- data.frame(
		group=c(rep("SP",3),rep("NSP",3),rep("nst",3),rep("nso",3),rep("hFIB",4),rep("MSC",4),rep("ES",2)),
		sample=names(de.norm.p1.sub1),
		stringsAsFactors=F)
rownames(anno.col) <- anno.col[,2]

# unicode is working inside but not to PDF

pdf("de_marker_EwS_CSC.pdf", width=7, height=4)#, fonts="OpenSymbol")					# de_sub1...
pheatmap(de.norm.p1.sub1, main="DE sub", cluster_rows=F, clustering_distance_cols="correlation")
pheatmap(de.norm.p1.sub2.log2, main="DE sub log2", cluster_rows=F, clustering_distance_cols="correlation",
		annotation_row=anno.row[,1,drop=F],annotation_col=anno.col[,1,drop=F])
pheatmap(de.norm.p1.sub2.log2, main="DE sub log2", clustering_distance_rowss="correlation", clustering_distance_cols="correlation",
		annotation_row=anno.row[,1,drop=F],annotation_col=anno.col[,1,drop=F])
pheatmap(de.norm.p1.sub2.log2, main="DE sub log2", cluster_cols=F, clustering_distance_rows="correlation",
		annotation_row=anno.row[,1,drop=F],annotation_col=anno.col[,1,drop=F])
dev.off() #







# PSI & expression from DS

# add PIS columns
# Percent of Splice-In (PSI)
# Figure5 .. I find 0.79 (red) vs. 0.80 (blue). Common threshold for splicing analysis is often 0.05 or 0.1 as PSI difference
# PSI = inclusion reads / inclusion + exclusion reads

a <- c("s.B","s.C1","s.C2","s.D","s.B2","s.H1","s.H2","s.G1","s.G2", "s.E1","s.E2","s.E3")
f19(x.name=a, jcec=T)		# adds  PSI etc. to  's.'  tables  + write out as  'c.s.'  and   creates the  'counts.'  tables


#### export basic sets from above  (PSI extended version)  - counts_new_rMATStables -  for   suppl.info. ST1
a <- c("c.s.B","c.s.C1","c.s.C2","c.s.D","c.s.B2", "c.s.H1","c.s.H2","c.s.G1","c.s.G2", "c.s.E1","c.s.E2","c.s.E3")
for(i in 1:length(a)){
	b <- get(a[i])
	a1 <- names(b)
	for(j in 1:length(a1)){
		bpath <- "/home/korschi/on1/data/eclipseR/jMatschke/counts_new_rMATStables"
		write.table(b[[a1[j]]], file=paste(bpath,"/",a[i],".",a1[j],".tsv",sep=""), sep="\t", row.names=F, col.names=T)
	}
}


#### stat matrices
ls(pattern="^counts\\.")		# check if complete and order is right
f20(out.prefix="aa")		# creates 4 stat count matrices

write.table(aa.JC.FDR, file=paste(bpath,"/00_JC.FDR.tsv",sep=""), sep="\t", row.names=T, col.names=T)
write.table(aa.JC.PSI.FDR, file=paste(bpath,"/00_JC.PSI.FDR.tsv",sep=""), sep="\t", row.names=T, col.names=T)
write.table(aa.JEC.FDR, file=paste(bpath,"/00_JEC.FDR.tsv",sep=""), sep="\t", row.names=T, col.names=T)
write.table(aa.JEC.PSI.FDR, file=paste(bpath,"/00_JEC.PSI.FDR.tsv",sep=""), sep="\t", row.names=T, col.names=T)

a.lookup <- read.table("lookuptable.csv",header=T,sep="\t",stringsAsFactors=F)
f21(out.prefix="aa")		# creates 2 stat PSI matrices

write.table(aa.value.JC.PSI, file=paste(bpath,"/00_JC.PSI.values.tsv",sep=""), sep="\t", row.names=T, col.names=T)			# PSI all JC 305
write.table(aa.value.JEC.PSI, file=paste(bpath,"/00_JEC.PSI.values.tsv",sep=""), sep="\t", row.names=T, col.names=T)			# PSI all JCEC 787

length(unique(aa.value.JC.PSI[,4]))		# 215 unique genes
length(unique(aa.value.JEC.PSI[,4]))	# 476 unique genes


# customize base table further
aa.value.JC.PSI.2 <- cbind( t(sapply(strsplit(aa.value.JC.PSI[,1], split=".", fixed=T), rbind) )[,2:4], aa.value.JC.PSI)
aa.value.JEC.PSI.2 <- cbind( t(sapply(strsplit(aa.value.JEC.PSI[,1], split=".", fixed=T), rbind) )[,2:4], aa.value.JEC.PSI)

# some trials
library(pheatmap)

pdf("ds_all_st_psi_JC_heat.pdf", width=7, height=10)					# ds psi

a2 <- aa.value.JC.PSI.2[order(aa.value.JC.PSI.2[,2]), c(2,7)]
names(a2) <- c("splice type","gene")
a <- log2(aa.value.JC.PSI.2[order(aa.value.JC.PSI.2[,2]), c(10:13)])
pheatmap(a, main="all DS - splice type - JC",
		cluster_cols=F, cluster_rows=F, clustering_distance_rows="correlation", show_rownames=F, show_colnames=T,
		annotation_row=a2[,1,drop=F])

## row norm
#a2 <- aa.value.JC.PSI.2[order(aa.value.JC.PSI.2[,2]), c(2,7)]
#names(a2) <- c("splice type","gene")
#a <- aa.value.JC.PSI.2[order(aa.value.JC.PSI.2[,2]), c(10:13)]
#b1 <- a[a2[,1]=="A3",]
#b1 <- b1[order(b1[,1]),]
#b2 <- a[a2[,1]=="A5",]
#b2 <- b2[order(b2[,1]),]
#b3 <- a[a2[,1]=="MX",]
#b3 <- b3[order(b3[,1]),]
#b4 <- a[a2[,1]=="RI",]
#b4 <- b4[order(b4[,1]),]
#b5 <- a[a2[,1]=="SE",]
#b5 <- b5[order(b5[,1]),]
##a <- t(apply(a, 1, function(x){ a <- x[1:2]/max(x[1:2]); b <- x[3:4]/max(x[3:4]); return(c(a,b)) }))
#pheatmap(log(rbind(b1,b2,b3,b4,b5),2), main="all DS - splice type - JC",
#		cluster_cols=F, cluster_rows=F, clustering_distance_rows="correlation", show_rownames=F, show_colnames=T,
#		annotation_row=a2[,1,drop=F])

a2 <- aa.value.JC.PSI.2[order(aa.value.JC.PSI.2[,2]), c(2,7)]
names(a2) <- c("splice type","gene")
a <- log2(aa.value.JC.PSI.2[order(aa.value.JC.PSI.2[,2]), c(8:9)])
pheatmap(a, main="all DS - psi - JC",
		cluster_cols=F, cluster_rows=F, clustering_distance_rows="correlation", show_rownames=F, show_colnames=T,
		annotation_row=a2[,1,drop=F])
dev.off()



# tab1 #
de.nsp.g1 <- c("POLDIP3", "RMDN1", "SMARCB1") # NSP i G1
de.nsp.g2 <- c("SELENBP1", "ZFAND1", "ZNF283", "AC022826.2") # NSP i G2		# "AC022826.2": paralog: UBE2W, even not in the raw data..., annotation changed in-between... ?
de.nsp.gc <- c("ACADVL", "LMO7", "NOP58", "TM7SF3", "TSPAN3") # NSP i G common

de.bcuni.h1 <- c("ATP13A3", "HLCS", "OGT", "POC5", "TCAIM", "TRA2A") # SP i H1
de.bcuni.h2 <- c("KMO", "SNHG1", "STRADA", "TRDMT1") # SP i H2
de.bcuni.hc <- c("EPB41", "SNHG17") # SP i H common

de.nsp.bcuni.all <- c(de.nsp.g1,de.nsp.g2,de.nsp.gc, de.bcuni.h1,de.bcuni.h2,de.bcuni.hc)

#
aa.nsp.bcuni.all.psi.JC <- f22(x=aa.value.JC.PSI, genes=de.nsp.bcuni.all, column=4)
aa.nsp.bcuni.all.psi.JEC <- f22(x=aa.value.JEC.PSI, genes=de.nsp.bcuni.all, column=4)

write.table(aa.nsp.bcuni.all.psi.JC, file=paste(bpath,"/01_JC.PSI.tab5.tsv",sep=""), sep="\t", row.names=T, col.names=T)
write.table(aa.nsp.bcuni.all.psi.JEC, file=paste(bpath,"/01_JEC.PSI.tab5.tsv",sep=""), sep="\t", row.names=T, col.names=T)


# get all DS core set tab4 lines out of c.s. objects (not filtered)
de.nsp.g1 <- c("^POLDIP3", "^RMDN1", "^SMARCB1") # NSP i G1
de.nsp.g2 <- c("^SELENBP1", "^ZFAND1", "^ZNF283", "^AC022826.2") # NSP i G2		# "AC022826.2": paralog: UBE2W, even not in the raw data..., annotation changed in-between... ?
de.nsp.gc <- c("^ACADVL", "^LMO7", "^NOP58", "^TM7SF3", "^TSPAN3") # NSP i G common

de.bcuni.h1 <- c("^ATP13A3", "^HLCS", "^OGT", "^POC5", "^TCAIM", "^TRA2A") # SP i H1
de.bcuni.h2 <- c("^KMO", "^SNHG1", "^STRADA", "^TRDMT1") # SP i H2
de.bcuni.hc <- c("^EPB41", "^SNHG17") # SP i H common

de.nsp.bcuni.all <- c(de.nsp.g1,de.nsp.g2,de.nsp.gc, de.bcuni.h1,de.bcuni.h2,de.bcuni.hc)

#c("geneSymbol","chr","strand","FDR","IncLevel1","IncLevel2","IncLevelDifference",
#		"PSI_sum_s1","PSI_sum_s2","s1_IJC_counts","s1_SJC_counts","s2_IJC_counts","s2_SJC_counts")

a <- ls(pattern="^c\\.s\\.")
aa.tab4.JC.all <- find.gene.names.3(a, query=de.nsp.bcuni.all, s.col=4, JC.EC=1:5)
aa.tab4.JCEC.all <- find.gene.names.3(a, query=de.nsp.bcuni.all, s.col=4, JC.EC=6:10)

write.table(aa.tab4.JC.all, file=paste(bpath,"/02_JC.PSI.tab4.tsv",sep=""), sep="\t", row.names=T, col.names=T)
write.table(aa.tab4.JCEC.all, file=paste(bpath,"/02_JEC.PSI.tab4.tsv",sep=""), sep="\t", row.names=T, col.names=T)

save.image()





# customize in calc
aa.nsp.bcuni.all.psi <- read.table(file="table5genesPSI.csv", header=T, sep="\t")
names(aa.nsp.bcuni.all.psi) <- c("index","annotation","group1","group2","gene.symbol",
						"PSI1","PSI2","inclusion1","exclusion1","inclusion2","exclusion2")

anno.row <- aa.nsp.bcuni.all.psi[,2,drop=F]
anno.row[,1] <- apply(anno.row[,1,drop=F],1, gsub, pattern="counts.", replacement="", fixed=T)
anno.row[,1] <- apply(anno.row[,1,drop=F],1, gsub, pattern="G1erg.", replacement="G1.", fixed=T)
anno.row[,1] <- apply(anno.row[,1,drop=F],1, gsub, pattern="G2fli.", replacement="G2.", fixed=T)
anno.row[,1] <- apply(anno.row[,1,drop=F],1, gsub, pattern="H1erg.", replacement="H1.", fixed=T)
anno.row[,1] <- apply(anno.row[,1,drop=F],1, gsub, pattern="H2fli.", replacement="H2.", fixed=T)
anno.row[,1] <- apply(anno.row[,1,drop=F],1, gsub, pattern="MX.", replacement="MXE.", fixed=T)
anno.row[,1] <- apply(anno.row[,1,drop=F],1, gsub, pattern="A3.", replacement="A3SS", fixed=T)
anno.row[,1] <- apply(anno.row[,1,drop=F],1, sub, pattern=".JEC", replacement=".JCEC", fixed=T)
anno.row[,1] <- apply(anno.row[,1,drop=F],1, gsub, pattern=".", replacement=" ", fixed=T)
row.names(anno.row) <- paste(aa.nsp.bcuni.all.psi[,5], seq(1,34), sep="-")
row.names(aa.nsp.bcuni.all.psi) <- row.names(anno.row)


library(pheatmap)

pdf("ds_psi_heat.pdf", width=7, height=5)					# ds psi

pheatmap(aa.nsp.bcuni.all.psi[c(1:8),c(6,7)], main="DS tab5 JC", cluster_cols=F, cluster_rows=F, annotation_row=anno.row[c(1:8),1,drop=F])
pheatmap(aa.nsp.bcuni.all.psi[c(13:20),c(6,7)], main="DS tab5 JCEC", cluster_cols=F, cluster_rows=F, annotation_row=anno.row[c(13:20),1,drop=F])

pheatmap(log2(aa.nsp.bcuni.all.psi[c(1:8),c(8:11)]), main="DS tab5 JC log2", cluster_cols=F, cluster_rows=F, annotation_row=anno.row[c(1:8),1,drop=F])
pheatmap(log2(aa.nsp.bcuni.all.psi[c(13:20),c(8:11)]), main="DS tab5 JCEC log2", cluster_cols=F, cluster_rows=F, annotation_row=anno.row[c(13:20),1,drop=F])

pheatmap(log2(aa.nsp.bcuni.all.psi[c(1:8),c(8:11)]), main="DS tab5 JC log2", cluster_cols=F, cluster_rows=T, annotation_row=anno.row[c(1:8),1,drop=F])
pheatmap(log2(aa.nsp.bcuni.all.psi[c(13:20),c(8:11)]), main="DS tab5 JCEC log2", cluster_cols=F, cluster_rows=T, annotation_row=anno.row[c(13:20),1,drop=F])

dev.off()






#### intersections on the PSI level --- not working
ls(pattern="^counts\\.C1.*\\.JC")
c.s.C1uC2 <- f2(x=list(apply.PSI.filter2(counts.C1.A3.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C1.A5.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C1.MX.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C1.RI.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C1.SE.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C1.A3.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C1.A5.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C1.MX.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C1.RI.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C1.SE.JEC, s.col=c(2,3))),
		y=list(apply.PSI.filter2(counts.C2.A3.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C2.A5.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C2.MX.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C2.RI.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C2.SE.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C2.A3.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C2.A5.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C2.MX.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C2.RI.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.C2.SE.JEC, s.col=c(2,3))),
		idv=c(1,1), setfn="u", repl="C1uC2")
c.s.BCpre <- f2(x=c.s.C1uC2,
		y=list(apply.PSI.filter2(counts.B.A3.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B.A5.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B.MX.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B.RI.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B.SE.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B.A3.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B.A5.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B.MX.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B.RI.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B.SE.JEC, s.col=c(2,3))),
		idv=c(0,1), setfn="ue", repl="BCpre")		# 1: C1 C2, 2: BC
c.s.BC <- f3(x=c.s.BCpre, num=2, repl="BC")

# BC'
c.s.BCeDeB2 <- f4(x=c.s.BC,
		y=list(apply.PSI.filter2(counts.D.A3.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.D.A5.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.D.MX.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.D.RI.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.D.SE.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.D.A3.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.D.A5.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.D.MX.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.D.RI.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.D.SE.JEC, s.col=c(2,3))),
		z=list(apply.PSI.filter2(counts.B2.A3.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B2.A5.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B2.MX.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B2.RI.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B2.SE.JC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B2.A3.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B2.A5.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B2.MX.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B2.RI.JEC, s.col=c(2,3)),
				apply.PSI.filter2(counts.B2.SE.JEC, s.col=c(2,3))),
		idv=c(0,1,1), setfn="ue", repl="BCeDeB2")	# 1: BC, 2: D, 3: B2
c.s.BCunique <- f3(x=c.s.BCeDeB2, num=1, repl="BCuni")
c.s.Dunique <- f3(x=c.s.BCeDeB2, num=2, repl="Duni")
c.s.B2unique <- f3(x=c.s.BCeDeB2, num=3, repl="B2uni")

# -> not working with PSI from scratch (too sparse) because many good candidates vanish
# -> so rMATS sets need to be intersected and final candidates checked on PSI ratios




#### DS expression tables
library(pheatmap)
save.image()
# e.g. counts.B.A3.JC

# search in 'counts' table for genes
a <- ls(pattern="^counts\\.")		# 120
a1 <- c("^EWSR1$","^ERG$","^FLI$")
search.counts.EWS <- find.gene.names.2(xnames=a, query=a1, s.col=1)

results.counts.EWS <- fetch.gene.names.2(search.counts.EWS)
#write.table(results.counts.EWS, file=paste(bpath,"/0_DS.counts.EWS.tsv",sep=""), sep="\t", row.names=F, col.names=T)


# heat EWSR1 global

# search.counts.EWS			# EWSR1

a <- make.names(results.counts.EWS[,1], unique=T)
a <- sub(pattern="^counts\\.", replacement="", a)
row.names(results.counts.EWS) <- a

results.counts.EWS.2 <- results.counts.EWS[,c(5:8)]
range(results.counts.EWS.2)		# 0 4009
# change 0 to 0.5 (log2 -> -1) for graph purpose
results.counts.EWS.2[results.counts.EWS.2==0] <- 0.5
results.counts.EWS.2.log2 <- log2(results.counts.EWS.2)
range(results.counts.EWS.2.log2)

ds.corMat.EWSR1 <- cor(results.counts.EWS[,c(5:8)], use="c")

pdf("ds_EWSR1_PearsonCor_heat.pdf", width=7, height=9)
pheatmap(results.counts.EWS.2.log2, main="DS log2", cluster_cols=F, cluster_rows=T)
#pheatmap(results.counts.EWS[,c(3:6)], cluster_cols=F, cluster_rows=F, annotation_col=sampleInfo[,1,drop=F], annotation_row=anno.row[,1,drop=F])
pheatmap(ds.corMat.EWSR1, main="DS Pearson cor")
dev.off()


# heat NSPiG1 ... BCuniIH1 ...

# search.counts.fil.all1		# see below search PSI:  NSPiG1, NSPiG2, BCuniIH1, BCuniIH2
# options(width=200)
search.counts.fil.all1 <- search.counts.fil.all1[order(search.counts.fil.all1[,1]),]
cbind(seq(1,48),search.counts.fil.all1[,c(1,3,6:9)])
a1 <- search.counts.fil.all1[c(1,24, 25,27,28,30,32,33,35,37,38,39,41,42,44,45,47,48),]
a1 <- search.counts.fil.all1[c(25,27,28,30,32,33,35,37,38,39,41,42,44,45,47,48),]
a1 <- search.counts.fil.all1[c(1,24),]
# search.counts.fil.B0			# B
search.counts.fil.B0 <- search.counts.fil.B0[order(search.counts.fil.B0[,1]),]
cbind(seq(1,252),search.counts.fil.B0[,c(1,3,6:9)])
a1 <- search.counts.fil.B0[c(1,2,5,9,10,11,12,13,14,15,29),]
# search.counts.fil.BC0			# BC
search.counts.fil.BC0 <- search.counts.fil.BC0[order(search.counts.fil.BC0[,1]),]
cbind(seq(1,150),search.counts.fil.BC0[,c(1,3,6:9)])
a1 <- search.counts.fil.BC0[c(1,2,5,9,10,11,12,18),]
# search.counts.fil.BCuni0		# BCuni
search.counts.fil.BCuni0 <- search.counts.fil.BCuni0[order(search.counts.fil.BCuni0[,1]),]
cbind(seq(1,36),search.counts.fil.BCuni0[,c(1,3,6:9)])
a1 <- search.counts.fil.BCuni0[c(1,2,5),]
# search.counts.fil.POLR2A.b	# rev2
search.counts.fil.POLR2A.b <- search.counts.fil.BCuni0[order(search.counts.fil.POLR2A.b[,1]),]
cbind(seq(1,8),search.counts.fil.POLR2A.b[,c(1,3,6:9)])
a1 <- search.counts.fil.POLR2A.b[c(1,2,4,6),]

#a <- make.names(a1[,1], unique=T)
a <- sub(pattern="^counts\\.", replacement="", a1[,1])
a <- paste(a1[,3], a ,sep="-")
row.names(a1) <- a

a2 <- a1[,c(6:9)]
range(a2)		# 0 4009
# change 0 to 0.5 (log2 -> -1) for graph purpose
a2[a2==0] <- 0.5
a2.log2 <- log2(a2)
range(a2.log2)

a3 <- cor(a1[,c(6:9)], use="c")

pdf("ds_NSPiG1etal_PearsonCor_heat_c.pdf", width=7, height=2)
#pdf("ds_B_PearsonCor_heat.pdf", width=7, height=4)
#pdf("ds_BC_PearsonCor_heat.pdf", width=7, height=3)
#pdf("ds_BCuni_PearsonCor_heat.pdf", width=7, height=1.84)
#pdf("ds_POLR2A_PearsonCor_heat.pdf", width=7, height=2.4)
pheatmap(a2, main="ds as.is", cluster_cols=F, cluster_rows=T)
pheatmap(a2.log2, main="ds log2", cluster_cols=F, cluster_rows=T)
#pheatmap(results.counts.EWS[,c(3:6)], cluster_cols=F, cluster_rows=F, annotation_col=sampleInfo[,1,drop=F], annotation_row=anno.row[,1,drop=F])
pheatmap(a3, main="ds Pearson cor")
dev.off()

save.image()




#### special wish ETS list of wildtype genes  and POLR2A + interaction partners
# re-order
names(de.norm.p1)
de.norm.p2 <- de.norm.p1[,c(1:12,21,22,17:20,13:16)]

a <- c("EWSR1","FUS",  "FLI1","ERG","ETV1","ETV4","FEV")
a1 <- c("POLR2A",  "POLR2C","POLR2D","POLR2G","POLR2I","POLR2J","POLR2L","SUPT4H1")		# from POLR2A
a2 <- c("GTF2E1","INTS3","INTS6")				# to POLR2A
a <- c(a,a1,a2)
a2 <- de.norm.p2[a,]

write.table(round(a,0), file="0_special_wish.tsv", sep="\t", row.names=T, col.names=NA)


# annotation
sampleInfo <- data.frame(
		group=c("SP","SP","SP","NSP","NSP","NSP","nst","nst","nst","nso","nso","nso","ES","ES","MSC","MSC","MSC","MSC","hFIB","hFIB","hFIB","hFIB"),
		sample=c("SP1","SP2","SP3","NSP1","NSP2","NSP3","nst1","nst2","nst3","nso1","nso2","nso3","ES1","ES2","MSC1","MSC2","MSC3","MSC4","hFIB1","hFIB2","hFIB3","hFIB4"),
		stringsAsFactors=F)
rownames(sampleInfo) <- sampleInfo[,2]

rowInfo <- data.frame(
		group=c(rep("EWS-ETS",7), rep("POLR2A",11)),
		gene=a,
		stringsAsFactors=F)
rownames(rowInfo) <- rowInfo[,2]

a2.log2 <- log2(a2+0.1)

pdf("0wish_ETS_POLR2A_heat_d.pdf", width=7, height=5)
pheatmap(a2.log2, main="norm_expression ETS groups - log2", cluster_cols=F, cluster_rows=F)
pheatmap(a2.log2, main="norm_expression ETS groups - log2", cluster_cols=T, cluster_rows=F,
		clustering_distance_cols="correlation", annotation_col=sampleInfo[,1,drop=F], legend_labels=c("set","group2"))
dev.off()


# separate
a <- c("EWSR1","FUS",  "FLI1","ERG","ETV1","ETV4","FEV")
a1 <- c("POLR2A",  "POLR2C","POLR2D","POLR2G","POLR2I","POLR2J","POLR2L","SUPT4H1",  "GTF2E1","INTS3","INTS6")		# POLR2A et al.
a <- de.norm.p2[a,]
a1 <- de.norm.p2[a1,]

library(pheatmap)
save.image()

names(a)
names(a1)

a.log2 <- log2(a+0.1)
a1.log2 <- log2(a1+0.1)

pdf("0wish_ETS_heat_c.pdf", width=7, height=3)
pheatmap(a, main="norm_expression ETS groups", cluster_cols=F, cluster_rows=F)
pheatmap(a, main="norm_expression ETS groups", cluster_cols=F, cluster_rows=T, clustering_distance_rows="correlation", annotation_col=sampleInfo[,1,drop=F])
pheatmap(a, main="norm_expression ETS groups", cluster_cols=T, cluster_rows=T, clustering_distance_cols="correlation", clustering_distance_rows="correlation", annotation_col=sampleInfo[,1,drop=F])
pheatmap(a.log2, main="norm_expression ETS groups - log2", cluster_cols=F, cluster_rows=F)
pheatmap(a.log2, main="norm_expression ETS groups - log2", cluster_cols=F, cluster_rows=T, clustering_distance_rows="correlation", annotation_col=sampleInfo[,1,drop=F])
pheatmap(a.log2, main="norm_expression ETS groups - log2", cluster_cols=T, cluster_rows=T, clustering_distance_cols="correlation", clustering_distance_rows="correlation", annotation_col=sampleInfo[,1,drop=F])
dev.off()

pdf("0wish_POLR2A_heat_c.pdf", width=7, height=4)
pheatmap(a1, main="norm_expression POLR2A groups", cluster_cols=F, cluster_rows=F)
pheatmap(a1, main="norm_expression POLR2A groups", cluster_cols=F, cluster_rows=T, clustering_distance_rows="correlation", annotation_col=sampleInfo[,1,drop=F])
pheatmap(a1, main="norm_expression POLR2A groups", cluster_cols=T, cluster_rows=T, clustering_distance_cols="correlation", clustering_distance_rows="correlation", annotation_col=sampleInfo[,1,drop=F])
pheatmap(a1.log2, main="norm_expression POLR2A groups - log2", cluster_cols=F, cluster_rows=F)
pheatmap(a1.log2, main="norm_expression POLR2A groups - log2", cluster_cols=F, cluster_rows=T, clustering_distance_rows="correlation", annotation_col=sampleInfo[,1,drop=F])
pheatmap(a1.log2, main="norm_expression POLR2A groups - log2", cluster_cols=T, cluster_rows=T, clustering_distance_cols="correlation", clustering_distance_rows="correlation", annotation_col=sampleInfo[,1,drop=F])
dev.off()




# alternate splicing

## rev2
a1 <- c("^EWSR1","^FUS",  "^FLI1","^ERG","^ETV1","^ETV4","^FEV")
search.counts.fil.ets <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)		# 0
write.table(search.counts.fil.ets, file=paste("0_search.counts.fil.ETS.tsv",sep=""), sep="\t", row.names=F, col.names=T)

#
a1 <- c("^POLR2","^GTF2E1","^TBP","^SUPT","^GCN5","^INTS")
search.counts.fil.POLR2A <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)		# 0
write.table(search.counts.fil.POLR2A, file=paste(bpath,"/0_search.counts.fil.POLR2A.tsv",sep=""), sep="\t", row.names=F, col.names=T)

#search.counts.fil.POLR2A.b <- search.counts.PSI.filter[as.numeric(search.counts.fil.POLR2A[,3]),]
#write.table(search.counts.fil.POLR2A.b, file=paste(bpath,"/0_search.counts.fil.POLR2A.b.tsv",sep=""), sep="\t", row.names=F, col.names=T)






#### search PSI
a <- ls(pattern="^counts\\.")		# 120
search.counts.PSI.hits <- find.PSI.diff(a, diff.gr=0.5, s.col=c(2,3))

# hit statistics - according to PSI difference
# return a top list at the appropriate level of top
search.counts.PSI.stat <- find.PSI.stat(a, s.col=c(2,3), interval=c(0,1), step.size=0.05)

plot(search.counts.PSI.stat$dist.stat[,1], search.counts.PSI.stat$dist.stat[,2],
		xlab="PSI difference (min. PSI=0, max. PSI=1)", ylab="found SV" )

search.counts.PSI.filter <- find.PSI.filter(a, s.col=c(2,3), psi1=c(0.1,0.90), psi2=c(0.1,0.90), diff=c(0.5,0.90))

# Tab. 5 sets
a <- c(ls(pattern="^counts\\.B"),
		ls(pattern="^counts\\.B2"),
		ls(pattern="^counts\\.D"),
		ls(pattern="^counts\\.G1"),
		ls(pattern="^counts\\.G2"),
		ls(pattern="^counts\\.H1"),
		ls(pattern="^counts\\.H2")
		) #80
search.counts.PSI.filter <- find.PSI.filter(a, s.col=c(2,3), psi1=c(0.1,0.90), psi2=c(0.1,0.90), diff=c(0.5,0.90))

a1 <- c("^EWSR1$","^ERG$","^FLI1$")
search.counts.fil.EWS <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0

a1 <- c("^ACADVL","^LMO7","^NOP58","^POLDIP3","^RMDN1","^SMARCB1","^TM7SF3","^TSPAN3")
search.counts.fil.NSPiG1 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)

a1 <- c("^AC022826.2","^ACADVL","^LMO7","^NOP58","^SELENBP1","^TM7SF3","^TSPAN3","^ZFAND1","^ZNF283")
search.counts.fil.NSPiG2 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)

a1 <- c("^ATP13A3","^EPB41","^HLCS","^OGT","^POC5","^SNHG17","^TCAIM","^TRA2A")
search.counts.fil.BCuniIH1 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)

a1 <- c("^EPB41","^KMO","^SNHG1","^SNHG17","^STRADA","^TRDMT1")
search.counts.fil.BCuniIH2 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)


search.counts.fil.all1 <- rbind(
		search.counts.PSI.filter[as.numeric(search.counts.fil.NSPiG1[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.NSPiG2[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuniIH1[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuniIH2[,3]),]
		)
unique(search.counts.fil.all1[,3])		# look in Sashimi plots
write.table(search.counts.fil.all1, file=paste(bpath,"/0_search.counts.fil.all1.tsv",sep=""), sep="\t", row.names=F, col.names=T)
write.table(unique(search.counts.fil.all1[,3]), file=paste(bpath,"/0_search.counts.fil.all1.unique.tsv",sep=""), sep="\t", row.names=F, col.names=T)


# BCuni
a1 <- s1.BCunique$BCuni.SE.JC
search.counts.fil.BCuni1 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BCunique$BCuni.A5.JC
search.counts.fil.BCuni2 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BCunique$BCuni.A3.JC
search.counts.fil.BCuni3 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BCunique$BCuni.MX.JC
search.counts.fil.BCuni4 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BCunique$BCuni.RI.JC
search.counts.fil.BCuni5 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0

a1 <- s1.BCunique$BCuni.SE.JC
search.counts.fil.BCuni6 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BCunique$BCuni.A5.JC
search.counts.fil.BCuni7 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BCunique$BCuni.A3.JC
search.counts.fil.BCuni8 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BCunique$BCuni.MX.JC
search.counts.fil.BCuni9 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BCunique$BCuni.RI.JC
search.counts.fil.BCuni10 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0

search.counts.fil.BCuni0 <- rbind(
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuni1[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuni2[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuni3[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuni4[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuni5[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuni6[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuni7[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuni8[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuni9[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BCuni10[,3]),]
		)
unique(search.counts.fil.BCuni0[,3])		# look in Sashimi plots
write.table(search.counts.fil.BCuni0, file=paste(bpath,"/0_search.counts.fil.BCuni0.tsv",sep=""), sep="\t", row.names=F, col.names=T)
write.table(unique(search.counts.fil.BCuni0[,3]), file=paste(bpath,"/0_search.counts.fil.BCuni0.unique.tsv",sep=""), sep="\t", row.names=F, col.names=T)


# BC
a1 <- s1.BC$BC.SE.JC
search.counts.fil.BC1 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BC$BC.A5.JC
search.counts.fil.BC2 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BC$BC.A3.JC
search.counts.fil.BC3 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BC$BC.MX.JC
search.counts.fil.BC4 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BC$BC.RI.JC
search.counts.fil.BC5 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0

a1 <- s1.BC$BC.SE.JC
search.counts.fil.BC6 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BC$BC.A5.JC
search.counts.fil.BC7 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BC$BC.A3.JC
search.counts.fil.BC8 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BC$BC.MX.JC
search.counts.fil.BC9 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.BC$BC.RI.JC
search.counts.fil.BC10 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0

search.counts.fil.BC0 <- rbind(
		search.counts.PSI.filter[as.numeric(search.counts.fil.BC1[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BC2[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BC3[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BC4[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BC5[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BC6[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BC7[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BC8[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BC9[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.BC10[,3]),]
)
unique(search.counts.fil.BC0[,3])		# look in Sashimi plots
write.table(search.counts.fil.BC0, file=paste(bpath,"/0_search.counts.fil.BC0.tsv",sep=""), sep="\t", row.names=F, col.names=T)
write.table(unique(search.counts.fil.BC0[,3]), file=paste(bpath,"/0_search.counts.fil.BC0.unique.tsv",sep=""), sep="\t", row.names=F, col.names=T)


# B
a1 <- s1.B$B.SE.JC
search.counts.fil.B1 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.B$B.A5.JC
search.counts.fil.B2 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.B$B.A3.JC
search.counts.fil.B3 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.B$B.MX.JC
search.counts.fil.B4 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.B$B.RI.JC
search.counts.fil.B5 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0

a1 <- s1.B$B.SE.JC
search.counts.fil.B6 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.B$B.A5.JC
search.counts.fil.B7 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.B$B.A3.JC
search.counts.fil.B8 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.B$B.MX.JC
search.counts.fil.B9 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0
a1 <- s1.B$B.RI.JC
search.counts.fil.B10 <- find.gene.names.2("search.counts.PSI.filter", query=a1, s.col=3)	# 0

search.counts.fil.B0 <- rbind(
		search.counts.PSI.filter[as.numeric(search.counts.fil.B1[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.B2[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.B3[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.B4[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.B5[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.B6[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.B7[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.B8[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.B9[,3]),],
		search.counts.PSI.filter[as.numeric(search.counts.fil.B10[,3]),]
)
unique(search.counts.fil.B0[,3])		# look in Sashimi plots
write.table(search.counts.fil.B0, file=paste(bpath,"/0_search.counts.fil.B0.tsv",sep=""), sep="\t", row.names=F, col.names=T)
write.table(unique(search.counts.fil.B0[,3]), file=paste(bpath,"/0_search.counts.fil.B0.unique.tsv",sep=""), sep="\t", row.names=F, col.names=T)





#### OR GO plots

#http://yulab-smu.top/clusterProfiler-book/chapter12.html
#BiocManager::install("clusterProfiler")		# here not necessary

#BiocManager::install("enrichplot")			# package of choice
#BiocManager::install("DOSE")
# not used too specific
save.image()

# ba (SV), bb joined
# columns : 1 GOterm 2: number 4:nes (normalized enrichment score) 6:FDR

#scfd.goAll.symbol$iddesc		# 1:id: GO:term 2:desc: description

# splice type
pdf("ds_10go_terms_bar_st.pdf",width=7, height=11)
# Table 5
# basic sets
ontology.wrap(ba.sp$sp.SE.JC$frequency, y=ba.sp$sp.SE.JC$infoID,
		column=2, sel=45, title.m="ba.sp")
ontology.wrap(ba.sp$sp.A5.JC$frequency, y=ba.sp$sp.A5.JC$infoID,
		column=2, sel=45, title.m="ba.sp")
ontology.wrap(ba.sp$sp.A3.JC$frequency, y=ba.sp$sp.A3.JC$infoID,
		column=2, sel=45, title.m="ba.sp")
ontology.wrap(ba.sp$sp.MX.JC$frequency, y=ba.sp$sp.MX.JC$infoID,
		column=2, sel=45, title.m="ba.sp")
ontology.wrap(ba.sp$sp.RI.JC$frequency, y=ba.sp$sp.RI.JC$infoID,
		column=2, sel=45, title.m="ba.sp")

ontology.wrap(ba.nsp$nsp.SE.JC$frequency, y=ba.nsp$nsp.SE.JC$infoID,
		column=2, sel=45, title.m="ba.nsp")
ontology.wrap(ba.nsp$nsp.A5.JC$frequency, y=ba.nsp$nsp.A5.JC$infoID,
		column=2, sel=45, title.m="ba.nsp")
ontology.wrap(ba.nsp$nsp.A3.JC$frequency, y=ba.nsp$nsp.A3.JC$infoID,
		column=2, sel=45, title.m="ba.nsp")
ontology.wrap(ba.nsp$nsp.MX.JC$frequency, y=ba.nsp$nsp.MX.JC$infoID,
		column=2, sel=45, title.m="ba.nsp")
ontology.wrap(ba.nsp$nsp.RI.JC$frequency, y=ba.nsp$nsp.RI.JC$infoID,
		column=2, sel=45, title.m="ba.nsp")

ontology.wrap(ba.msc$msc.SE.JC$frequency, y=ba.msc$msc.SE.JC$infoID,
		column=2, sel=45, title.m="ba.msc")
ontology.wrap(ba.msc$msc.A5.JC$frequency, y=ba.msc$msc.A5.JC$infoID,
		column=2, sel=45, title.m="ba.msc")
ontology.wrap(ba.msc$msc.A3.JC$frequency, y=ba.msc$msc.A3.JC$infoID,
		column=2, sel=45, title.m="ba.msc")
ontology.wrap(ba.msc$msc.MX.JC$frequency, y=ba.msc$msc.MX.JC$infoID,
		column=2, sel=45, title.m="ba.msc")
ontology.wrap(ba.msc$msc.RI.JC$frequency, y=ba.msc$msc.RI.JC$infoID,
		column=2, sel=45, title.m="ba.msc")

ontology.wrap(ba.BCunique$BCuni.SE.JC$frequency, y=ba.BCunique$BCuni.SE.JC$infoID,
		column=2, sel=45, title.m="ba.BCunique")
ontology.wrap(ba.BCunique$BCuni.A5.JC$frequency, y=ba.BCunique$BCuni.A5.JC$infoID,
		column=2, sel=45, title.m="ba.BCunique")
ontology.wrap(ba.BCunique$BCuni.A3.JC$frequency, y=ba.BCunique$BCuni.A3.JC$infoID,
		column=2, sel=45, title.m="ba.BCunique")
ontology.wrap(ba.BCunique$BCuni.MX.JC$frequency, y=ba.BCunique$BCuni.MX.JC$infoID,
		column=2, sel=45, title.m="ba.BCunique")
ontology.wrap(ba.BCunique$BCuni.RI.JC$frequency, y=ba.BCunique$BCuni.RI.JC$infoID,
		column=2, sel=45, title.m="ba.BCunique")

ontology.wrap(ba.Dunique$Duni.SE.JC$frequency, y=ba.Dunique$Duni.SE.JC$infoID,
		column=2, sel=45, title.m="ba.Dunique")
ontology.wrap(ba.Dunique$Duni.A5.JC$frequency, y=ba.Dunique$Duni.A5.JC$infoID,
		column=2, sel=45, title.m="ba.Dunique")
ontology.wrap(ba.Dunique$Duni.A3.JC$frequency, y=ba.Dunique$Duni.A3.JC$infoID,
		column=2, sel=45, title.m="ba.Dunique")
ontology.wrap(ba.Dunique$Duni.MX.JC$frequency, y=ba.Dunique$Duni.MX.JC$infoID,
		column=2, sel=45, title.m="ba.Dunique")
ontology.wrap(ba.Dunique$Duni.RI.JC$frequency, y=ba.Dunique$Duni.RI.JC$infoID,
		column=2, sel=45, title.m="ba.Dunique")

ontology.wrap(ba.B2unique$B2uni.SE.JC$frequency, y=ba.B2unique$B2uni.SE.JC$infoID,
		column=2, sel=45, title.m="ba.B2unique")
ontology.wrap(ba.B2unique$B2uni.A5.JC$frequency, y=ba.B2unique$B2uni.A5.JC$infoID,
		column=2, sel=45, title.m="ba.B2unique")
ontology.wrap(ba.B2unique$B2uni.A3.JC$frequency, y=ba.B2unique$B2uni.A3.JC$infoID,
		column=2, sel=45, title.m="ba.B2unique")
ontology.wrap(ba.B2unique$B2uni.MX.JC$frequency, y=ba.B2unique$B2uni.MX.JC$infoID,
		column=2, sel=45, title.m="ba.B2unique")
ontology.wrap(ba.B2unique$B2uni.RI.JC$frequency, y=ba.B2unique$B2uni.RI.JC$infoID,
		column=2, sel=45, title.m="ba.B2unique")
dev.off()

# joined
pdf("ds_10go_terms_bar.pdf",width=7, height=11)
# Table 5
ontology.wrap(bb.NSPiG1.joined$all_splice_ty_JC$frequency, y=bb.NSPiG1.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="bb.NSPiG1.joined")
ontology.wrap(bb.NSPiG2.joined$all_splice_ty_JC$frequency, y=bb.NSPiG2.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="bb.NSPiG2.joined")
ontology.wrap(bb.BCuniIH1.joined$all_splice_ty_JC$frequency, y=bb.BCuniIH1.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="bb.BCuniIH1.joined")
ontology.wrap(bb.BCuniIH2.joined$all_splice_ty_JC$frequency, y=bb.BCuniIH2.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="bb.BCuniIH2.joined")
# basic sets
ontology.wrap(bb.sp.joined$all_splice_ty_JC$frequency, y=bb.sp.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="bb.sp.joined")
ontology.wrap(bb.nsp.joined$all_splice_ty_JC$frequency, y=bb.nsp.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="bb.nsp.joined")
ontology.wrap(bb.msc.joined$all_splice_ty_JC$frequency, y=bb.msc.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="bb.msc.joined")

ontology.wrap(bb.BCunique.joined$all_splice_ty_JC$frequency, y=bb.BCunique.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="bb.BCunique.joined")
ontology.wrap(bb.Dunique.joined$all_splice_ty_JC$frequency, y=bb.Dunique.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="bb.Dunique.joined")
ontology.wrap(bb.B2unique.joined$all_splice_ty_JC$frequency, y=bb.B2unique.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="bb.B2unique.joined")
dev.off()

pdf("ds_10complex_bar.pdf",width=7, height=11)
# Table 5
ontology.wrap(cx.NSPiG1.joined$all_splice_ty_JC$frequency, y=cx.NSPiG1.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="cx.NSPiG1.joined")
ontology.wrap(cx.NSPiG2.joined$all_splice_ty_JC$frequency, y=cx.NSPiG2.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="cx.NSPiG2.joined")
ontology.wrap(cx.BCuniIH1.joined$all_splice_ty_JC$frequency, y=cx.BCuniIH1.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="cx.BCuniIH1.joined")
ontology.wrap(cx.BCuniIH2.joined$all_splice_ty_JC$frequency, y=cx.BCuniIH2.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="cx.BCuniIH2.joined")
# basic sets
ontology.wrap(cx.sp.joined$all_splice_ty_JC$frequency, y=cx.sp.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="cx.sp.joined")
ontology.wrap(cx.nsp.joined$all_splice_ty_JC$frequency, y=cx.nsp.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="cx.nsp.joined")
ontology.wrap(cx.msc.joined$all_splice_ty_JC$frequency, y=cx.msc.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="cx.msc.joined")

ontology.wrap(cx.BCunique.joined$all_splice_ty_JC$frequency, y=cx.BCunique.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="cx.BCunique.joined")
ontology.wrap(cx.Dunique.joined$all_splice_ty_JC$frequency, y=cx.Dunique.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="cx.Dunique.joined")
ontology.wrap(cx.B2unique.joined$all_splice_ty_JC$frequency, y=cx.B2unique.joined$all_splice_ty_JC$infoID,
		column=2, sel=45, title.m="cx.B2unique.joined")
dev.off()



#### find in CORUM
names(CORUM.core.hu)

#[1] "ComplexID"                           "ComplexName"                        
#[3] "Organism"                            "Synonyms"                           
#[5] "Cell.line"                           "subunits.UniProt.IDs."              
#[7] "subunits.Entrez.IDs."                "Protein.complex.purification.method"
#[9] "GO.ID"                               "GO.description"                     
#[11] "FunCat.ID"                           "FunCat.description"                 
#[13] "subunits.Gene.name.syn."             "Complex.comment"                    
#[15] "Disease.comment"                     "SWISSPROT.organism"                 
#[17] "Subunits.comment"                    "subunits.Gene.name."                
#[19] "PubMed.ID"                           "subunits.Protein.name."             

# ATP13A3, EPB41    ACADVL, NOP58, TSPAN3
a <- grepl(pattern="ATP13A3",x=CORUM.core.hu[,13],perl=T,fixed=F)
sum(a)	# 0

a <- grepl(pattern="EPB41",x=CORUM.core.hu[,13],perl=T,fixed=F)
sum(a)	# 0

a <- grepl(pattern="ACADVL",x=CORUM.core.hu[,13],perl=T,fixed=F)
sum(a)	# 0

a <- grepl(pattern="NOP58",x=CORUM.core.hu[,13],perl=T,fixed=F)
sum(a)	# 0

a <- grepl(pattern="TSPAN3",x=CORUM.core.hu[,13],perl=T,fixed=F)
sum(a)	# 2 -> TSPAN30 ! so: 0
corum.hit.tspan3 <- CORUM.core.hu[a,]










